@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: backgammon.h,v 1.285 2004/04/22 19:14:34 thyssen Exp $
+ * $Id: backgammon.h,v 1.313.2.2 2006/11/10 11:34:39 c_anthon Exp $
  */
 
 #ifndef _BACKGAMMON_H_
@@ -27,26 +27,16 @@
 #include <list.h>
 #include <math.h>
 #include <stdarg.h>
+#include <stdio.h>
 
 #include "analysis.h"
 #include "eval.h"
+#include "common.h"
 
 #if USE_TIMECONTROL && WIN32
 #include <winsock2.h>
 #endif
 
-#if !defined (__GNUC__) && !defined (__attribute__)
-#define __attribute__(X)
-#endif
-
-#ifdef HUGE_VALF
-#define ERR_VAL (-HUGE_VALF)
-#elif defined (HUGE_VAL)
-#define ERR_VAL (-HUGE_VAL)
-#else
-#define ERR_VAL (-FLT_MAX)
-#endif
-
 #if USE_GTK
 #include <gtk/gtk.h>
 extern GtkWidget* pwBoard;
@@ -55,34 +45,10 @@ extern guint nNextTurn; /* GTK idle function */
 #if USE_TIMECONTROL
 extern void GTKUpdateClock(void);
 #endif
-#elif USE_EXT
-#include <ext.h>
-#include <event.h>
-extern extwindow ewnd;
-extern int fX, nDelay, fNeedPrompt;
-extern event evNextTurn;
-#endif
-
-#if HAVE_SIGACTION
-typedef struct sigaction psighandler;
-#elif HAVE_SIGVEC
-typedef struct sigvec psighandler;
-#else
-typedef RETSIGTYPE (*psighandler)( int );
 #endif
 
 #define MAX_CUBE ( 1 << 12 )
 
-#ifdef WIN32
-#include <stdlib.h>
-#define BIG_PATH _MAX_PATH
-#else
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
-#endif
-#define BIG_PATH PATH_MAX
-#endif
-
 /* position of windows: main window, game list, and annotation */
 
 typedef enum _gnubgwindow {
@@ -92,36 +58,24 @@ typedef enum _gnubgwindow {
   WINDOW_ANNOTATION,
   WINDOW_HINT,
   WINDOW_MESSAGE,
-  NUM_WINDOWS 
+  WINDOW_COMMAND,
+  WINDOW_THEORY,
+  NUM_WINDOWS
 } gnubgwindow;
 
 typedef struct _windowgeometry {
   int nWidth, nHeight;
-  int nPosX, nPosY;
+  int nPosX, nPosY, max;
 } windowgeometry;
 
-typedef struct _windowobject {
-	char* winName;
-	int showing;
-	int docked;
-	int dockable;
-	int undockable;
-#if USE_GTK
-	GtkWidget* pwWin;
-#endif
-	windowgeometry wg;
-} windowobject;
+extern void SaveWindowSettings(FILE* pf);
+extern void HidePanel(gnubgwindow window);
+extern void getWindowGeometry(gnubgwindow window);
+extern int PanelShowing(gnubgwindow window);
+extern void ClosePanels();
 
-extern windowobject woPanel[NUM_WINDOWS];
-
-typedef struct _monitor {
-#if USE_GTK
-    int fGrab;
-    int idSignal;
-#else
-	int dummy;
-#endif
-} monitor;
+extern int GetPanelSize();
+extern void SetPanelWidth(int size);
 
 typedef struct _command {
   /* Command name (NULL indicates end of list) */
@@ -172,7 +126,7 @@ typedef enum _movetype {
     MOVE_TIME
 } movetype;
 
-#ifdef USE_TIMECONTROL
+#if USE_TIMECONTROL
 
 #include <time.h>
 #if HAVE_SYS_TIME_H
@@ -256,13 +210,6 @@ typedef struct _gameclock {
 #endif
 
 typedef struct _movegameinfo {
-  /* "standard" header */
-  movetype mt;
-  char* sz;
-#if USE_TIMECONTROL
-  /* time left after the move */
-  struct timeval tl[2];
-#endif
 
   /* ordinal number of the game within a match */
   int i;
@@ -306,7 +253,7 @@ typedef struct _movegameinfo {
   /* how many timeouts (clock expiry) have happened during the match */
     int nTimeouts[2];
 #endif
-} movegameinfo;
+} xmovegameinfo;
 
 typedef struct cubedecisiondata {
   float aarOutput[ 2 ][ NUM_ROLLOUT_OUTPUTS ];
@@ -314,67 +261,18 @@ typedef struct cubedecisiondata {
   evalsetup esDouble;
 } cubedecisiondata;
 
-typedef struct _movedouble {
-    movetype mt;
-    char* sz;
-#if USE_TIMECONTROL
-    struct timeval tl[2];
-#endif
-    int fPlayer;
-    int nAnimals;    /* 0 in match play, even numbers are doubles, raccoons
-                        odd numbers are beavers, aardvarken, etc. */
-    cubedecisiondata* CubeDecPtr;
-    cubedecisiondata  CubeDec;
-    skilltype st;
-} movedouble;
-
 typedef struct _movenormal {
-  /* "standard" header */
-  movetype mt;
-  char* sz;
-#if USE_TIMECONTROL
-  struct timeval tl[2];
-#endif
-
-  int fPlayer;
-
-  /* dice for move */ 
-  int anRoll[2];
 
   /* Move made. */
   int anMove[ 8 ];
 
-  /* evaluation setup for move analysis */
-  evalsetup esChequer;
-
-  /* evaluation of cube action before this move */
-  float aarOutput[ 2 ][ NUM_ROLLOUT_OUTPUTS ];
-  float aarStdDev[ 2 ][ NUM_ROLLOUT_OUTPUTS ];
-
-  evalsetup esDouble;
-
-  /* evaluation of the moves */
-  movelist ml;
-
   /* index into the movelist of the move that was made */
   int iMove; 
 
-  lucktype lt;
-
-  /* ERR_VAL means unknown */
-  float rLuck; 
-
   skilltype stMove;
-  skilltype stCube;
-} movenormal;
+} xmovenormal;
 
 typedef struct _moveresign {
-    movetype mt;
-    char* sz;
-#if USE_TIMECONTROL
-    struct timeval tl[2];
-#endif
-    int fPlayer;
     int nResigned;
 
     evalsetup esResign;
@@ -382,81 +280,93 @@ typedef struct _moveresign {
 
     skilltype stResign;
     skilltype stAccept;
-} moveresign;
+} xmoveresign;
 
 typedef struct _movesetboard {
-    movetype mt;
-    char* sz;
-#if USE_TIMECONTROL
-    struct timeval tl[2];
-#endif
     unsigned char auchKey[ 10 ]; /* always stored as if player 0 was on roll */
-} movesetboard;
-
-typedef struct _movesetdice {
-    movetype mt;
-    char* sz;
-#if USE_TIMECONTROL
-    struct timeval tl[2];
-#endif
-    int fPlayer;
-    int anDice[ 2 ];
-    lucktype lt;
-    float rLuck; /* ERR_VAL means unknown */
-} movesetdice;
+} xmovesetboard;
 
 typedef struct _movesetcubeval {
-    movetype mt;
-    char* sz;
-#if USE_TIMECONTROL
-    struct timeval tl[2];
-#endif
     int nCube;
-} movesetcubeval;
+} xmovesetcubeval;
 
 typedef struct _movesetcubepos {
-    movetype mt;
-    char *sz;
-#if USE_TIMECONTROL
-    struct timeval tl[2];
-#endif
     int fCubeOwner;
-} movesetcubepos;
+} xmovesetcubepos;
 
 #if USE_TIMECONTROL
 typedef struct _movetime {
-    movetype mt;
-    char *sz;
-    struct timeval tl[2];
-    int fPlayer;
     int nPoints;
 
     /* evaluation of loss */
     float aarOutput[ 2 ][ NUM_ROLLOUT_OUTPUTS ];
     float aarStdDev[ 2 ][ NUM_ROLLOUT_OUTPUTS ];
     evalsetup es;
-} movetime;
+} xmovetime;
 #endif
 
-typedef union _moverecord {
+typedef struct _moverecord {
+
+  /* 
+   * Common variables
+   */
+
+  /* type of the move */
     movetype mt;
-    struct _moverecordall {
-	movetype mt;
-	char* sz;
+
+  /* annotation */
+  char* sz;
+
+  /* stuff for timing */
 #if USE_TIMECONTROL
-	struct timeval tl[2];
+  struct timeval tl[2];
 #endif
-    } a;
-    movegameinfo g;
-    movedouble d; /* cube decisions */
-    movenormal n;
-    moveresign r;
-    movesetboard sb;
-    movesetdice sd;
-    movesetcubeval scv;
-    movesetcubepos scp;
+
+  /* move record is for player */
+  int fPlayer;
+
+  /* luck analysis (shared between MOVE_SETDICE and MOVE_NORMAL) */
+
+  /* dice rolled */
+  int anDice[ 2 ];
+
+  /* classification of luck */
+  lucktype lt;
+
+  /* magnitude of luck */
+  float rLuck; /* ERR_VAL means unknown */
+
+  /* move analysis (shared between MOVE_SETDICE and MOVE_NORMAL) */
+
+  /* evaluation setup for move analysis */
+  evalsetup esChequer;
+
+  /* evaluation of the moves */
+  movelist ml;
+
+  /* cube analysis (shared between MOVE_NORMAL and MOVE_DOUBLE) */
+
+  /* 0 in match play, even numbers are doubles, raccoons 
+     odd numbers are beavers, aardvarken, etc. */
+  int nAnimals;    
+
+  /* the evaluation and settings */
+  cubedecisiondata* CubeDecPtr;
+  cubedecisiondata  CubeDec;
+
+  /* skill for the cube decision */
+  skilltype stCube;
+
+  /* "private" data */
+
+  xmovegameinfo g;     /* game information */
+  xmovenormal n;       /* chequerplay move */
+  xmoveresign r;       /* resignation */
+  xmovesetboard sb;    /* setting up board */
+  xmovesetcubeval scv; /* setting cube */
+  xmovesetcubepos scp; /* setting cube owner */
 #if USE_TIMECONTROL
-    movetime t;
+  xmovetime t;         /* time controls */
 #endif
 } moverecord;
 
@@ -502,11 +412,11 @@ extern int fNextTurn, fComputing;
 
 /* User settings. */
 extern int fAutoGame, fAutoMove, fAutoRoll, fAutoCrawford, cAutoDoubles,
-    fCubeUse, fDisplay, fDockPanels, fAutoBearoff, fShowProgress,
+    fCubeUse, fDisplay, fAutoBearoff, fShowProgress,
     nBeavers, fJacoby,
     fOutputRawboard, cAnalysisMoves, fAnalyseCube,
     fAnalyseDice, fAnalyseMove, fRecord,
-	nDefaultLength, nToolbarStyle;
+	nDefaultLength, nToolbarStyle, fStyledGamelist, fFullScreen;
 extern int fInvertMET;
 extern int fConfirm, fConfirmSave;
 extern float rAlpha, rAnneal, rThreshold, arLuckLevel[ LUCK_VERYGOOD + 1 ],
@@ -523,12 +433,12 @@ extern char szLang[ 32 ];
 
 typedef enum _pathformat {
   PATH_EPS, PATH_GAM, PATH_HTML, PATH_LATEX, PATH_MAT, PATH_OLDMOVES,
-  PATH_PDF, PATH_POS, PATH_POSTSCRIPT, PATH_SGF, PATH_SGG, PATH_TEXT, 
+  PATH_PDF, PATH_PNG, PATH_POS, PATH_POSTSCRIPT, PATH_SGF, PATH_SGG, PATH_TEXT, 
   PATH_MET, PATH_TMG, PATH_BKG, PATH_SNOWIE_TXT,
-  NUM_PATHS } 
+  NUM_PATHS, PATH_NULL } 
 pathformat;
 
-extern char aaszPaths[ NUM_PATHS ][ 2 ][ 255 ];
+extern char aaszPaths[ NUM_PATHS ][ 2 ][ BIG_PATH ];
 extern char* aszExtensions[ NUM_PATHS ];
 extern char* szCurrentFileName;
 
@@ -609,6 +519,8 @@ extern char* NextToken( char **ppch );
 extern char* NextTokenGeneral( char **ppch, const char* szTokens );
 extern int NextTurn( int fPlayNext );
 extern void TurnDone( void );
+extern moverecord *
+NewMoveRecord( void );
 extern void AddMoveRecord( void* pmr );
 extern moverecord* LinkToDouble( moverecord* pmr);
 extern void ApplyMoveRecord( matchstate* pms, const list* plGame,
@@ -626,7 +538,6 @@ extern void ClearMatch( void );
 extern void FreeMatch( void );
 extern void SetMatchDate( matchinfo* pmi );
 extern int GetMatchStateCubeInfo( cubeinfo* pci, const matchstate* pms);
-extern int ParseHighlightColour( char* sz );
 extern int ParseNumber( char **ppch );
 extern int ParsePlayer( char* sz );
 extern int ParsePosition( int an[ 2 ][ 25 ], char **ppch, char* pchDesc );
@@ -687,9 +598,9 @@ extern void outputoff( void );
 extern void outputon( void );
 
 /* Temporarily ignore TTY/GUI input. */
-extern void SuspendInput( monitor* pm );
+extern void SuspendInput();
 /* Resume input (must match a previous SuspendInput). */
-extern void ResumeInput( monitor* pm );
+extern void ResumeInput();
 
 extern void ProgressStart( char* sz );
 extern void ProgressStartValue( char* sz, int iMax );
@@ -698,25 +609,17 @@ extern void ProgressValue ( int iValue );
 extern void ProgressValueAdd ( int iValue );
 extern void ProgressEnd( void );
 
-#if USE_GUI
 #if USE_GTK
 extern gint NextTurnNotify( gpointer p );
-#else
-extern int NextTurnNotify( event* pev, void* p );
-#endif
 extern void UserCommand( char* sz );
 extern void HandleXAction( void );
 #if HAVE_LIBREADLINE
 extern int fReadingCommand;
-extern void HandleInput( char* sz );
+extern void ProcessInput( char* sz );
 #endif
-#endif
-#if USE_GUI
-#if USE_GTK
 extern void HideAllPanels ( gpointer *p, guint n, GtkWidget *pw );
 extern void ShowAllPanels ( gpointer *p, guint n, GtkWidget *pw );
 #endif
-#endif
 
 #if HAVE_LIBREADLINE
 extern int fReadline;
@@ -751,6 +654,8 @@ getCurrentMoveRecord ( int* pfHistory );
 extern int
 getFinalScore( int* anScore );
 
+extern char* GetMoveString(moverecord *pmr, int* pPlayer);
+
 extern void
 UpdateStoredMoves ( const movelist* pml, const matchstate* pms );
 
@@ -766,8 +671,10 @@ InvalidateStoredMoves( void );
 extern void
 InvalidateStoredCube( void );
 
-extern char* aszVersion[], *szHomeDirectory, *szDataDirectory,
-    *szTerminalCharset;
+#define VERSION_STRING "GNU Backgammon " VERSION
+
+extern char *GetBuildInfoString();
+extern char *szHomeDirectory, *szDataDirectory;
 
 extern char* aszSkillType[], *aszSkillTypeAbbr[], *aszLuckType[],
     *aszLuckTypeAbbr[], *aszSkillTypeCommand[], *aszLuckTypeCommand[];
@@ -777,15 +684,13 @@ extern command acDatabase[], acNew[], acSave[], acSetAutomatic[],
     acSetRollout[], acSetRolloutLate[], acSetRolloutLimit[], 
   acSetTruncation [], acSetRolloutJsd[],
     acSet[], acShow[], acTrain[], acTop[], acSetMET[], acSetEvalParam[],
-    acSetRolloutPlayer[], acSetRolloutLatePlayer[], cOnOff, cFilename,
-    cHighlightColour;
+    acSetRolloutPlayer[], acSetRolloutLatePlayer[], cOnOff, cFilename;
 extern command acSetCheatPlayer[];
 extern command acSetAnalysisPlayer[];
 
 extern command acAnnotateMove[];
 extern command acSetExportParameters[];
 extern command acSetGeometryValues[];
-extern command acSetHighlightIntensity[];
 
 extern float rRatingOffset;
 
@@ -804,6 +709,7 @@ extern void CommandAccept( char * ),
     CommandAnalyseSession( char * ),
     CommandAnnotateAccept ( char * ),
     CommandAnnotateBad( char * ),
+    CommandAnnotateAddComment( char * ),
     CommandAnnotateClearComment( char * ),
     CommandAnnotateClearLuck( char * ),
     CommandAnnotateClearSkill( char * ),
@@ -903,7 +809,15 @@ extern void CommandAccept( char * ),
     CommandRecordEraseAll( char * ),
     CommandRecordShow( char * ),
     CommandRelationalAddMatch( char * ),
+    CommandRelationalAddEnvironment( char * ),
+    CommandRelationalErase( char * ),
+    CommandRelationalEraseEnv( char * ),
+    CommandRelationalEraseAll( char * ),
+    CommandRelationalRenameEnv( char * ),
+    CommandRelationalSelect( char * ),
     CommandRelationalShowEnvironments( char * ),
+    CommandRelationalShowPlayers( char * ),
+    CommandRelationalShowDetails( char * ),
     CommandRelationalTest( char * ),
     CommandRelationalHelp( char * ),
     CommandResign( char * ),
@@ -956,6 +870,7 @@ extern void CommandAccept( char * ),
     CommandSetCheatPlayer ( char * ),
     CommandSetCheatPlayerRoll ( char * ),
     CommandSetClockwise( char * ),
+    CommandSetCommandWindow ( char * ),
     CommandSetConfirmNew( char * ),
     CommandSetConfirmSave( char * ),
     CommandSetCrawford( char * ),
@@ -982,6 +897,7 @@ extern void CommandAccept( char * ),
     CommandSetEvalNoise( char * ),    
     CommandSetEvalPlies( char * ),
     CommandSetEvalReduced ( char * ),
+    CommandSetEvalPrune ( char * ),
     CommandSetEvalTolerance( char * ),
     CommandSetEvaluation( char * ),
     CommandSetEvalParamType( char * ),
@@ -991,6 +907,7 @@ extern void CommandAccept( char * ),
     CommandSetEvalCubedecision ( char * ),
     CommandSetEvalMoveFilter ( char * ),
     CommandSetEgyptian( char * ),
+    CommandSetExportFileType(char *sz),
     CommandSetExportIncludeAnnotations ( char * ),
     CommandSetExportIncludeAnalysis ( char * ),
     CommandSetExportIncludeStatistics ( char * ),
@@ -1031,16 +948,20 @@ extern void CommandAccept( char * ),
     CommandSetExportParametersRollout ( char * ),
     CommandSetExportPNGSize ( char *),
     CommandSetExportHtmlSize ( char *),
+    CommandSetFullScreen ( char * ),
     CommandSetGameList ( char * ),
     CommandSetGeometryAnalysis( char * ),
+    CommandSetGeometryCommand ( char * ),
     CommandSetGeometryGame ( char * ),
     CommandSetGeometryHint ( char * ),
     CommandSetGeometryMain ( char * ),
     CommandSetGeometryMessage ( char * ),
+    CommandSetGeometryTheory ( char * ),
     CommandSetGeometryWidth ( char * ),
     CommandSetGeometryHeight ( char * ),
     CommandSetGeometryPosX ( char * ),
     CommandSetGeometryPosY ( char * ),
+    CommandSetGeometryMax ( char * ),
     CommandSetGotoFirstGame( char * ),
     CommandSetGUIAnimationBlink( char * ),
     CommandSetGUIAnimationNone( char * ),
@@ -1056,11 +977,8 @@ extern void CommandAccept( char * ),
     CommandSetGUIShowEPCs( char * ),
     CommandSetGUIDragTargetHelp( char * ),
     CommandSetGUIUseStatsPanel( char * ),
-    CommandSetHighlight ( char * ),
-    CommandSetHighlightColour ( char * ),
-    CommandSetHighlightDark ( char * ),
-    CommandSetHighlightLight ( char * ),
-    CommandSetHighlightMedium ( char * ),
+    CommandSetGUIMoveListDetail( char * ),
+    CommandSetImportFileType(char *sz),
     CommandSetInvertMatchEquityTable( char * ),
     CommandSetJacoby( char * ),
     CommandSetLang( char * ),
@@ -1082,6 +1000,7 @@ extern void CommandAccept( char * ),
     CommandSetOutputRawboard( char * ),
     CommandSetOutputWinPC( char * ),
     CommandSetOutputErrorRateFactor( char * ),
+    CommandSetPanelWidth( char * ),
     CommandSetPathEPS( char * ),
     CommandSetPathSGF( char * ),
     CommandSetPathLaTeX( char * ),
@@ -1092,6 +1011,7 @@ extern void CommandAccept( char * ),
     CommandSetPathSGG( char * ),
     CommandSetPathTMG( char * ),
     CommandSetPathOldMoves( char * ),
+    CommandSetPathPNG( char * ),
     CommandSetPathPos( char * ),
     CommandSetPathGam( char * ),
     CommandSetPathPostScript( char * ),
@@ -1202,6 +1122,7 @@ extern void CommandAccept( char * ),
     CommandSetSoundSoundResign ( char * ),
     CommandSetSoundSoundRoll ( char * ),
     CommandSetSoundSoundStart ( char * ),
+    CommandSetStyledGameList ( char * ),
     CommandSetSoundSoundTake ( char * ),
 #if USE_TIMECONTROL
     CommandSetTCMove( char * ),
@@ -1216,6 +1137,7 @@ extern void CommandAccept( char * ),
     CommandSetTCUnname( char * ),
     CommandSetTimeControl( char * ),
 #endif
+    CommandSetTheoryWindow ( char * ),
     CommandSetToolbar( char * ),
     CommandSetTrainingAlpha( char * ),
     CommandSetTrainingAnneal( char * ),
@@ -1261,9 +1183,9 @@ extern void CommandAccept( char * ),
     CommandShowFullBoard( char * ),
     CommandShowGammonValues( char * ),
     CommandShowGeometry ( char * ),
-    CommandShowHighlightColour ( char * ),
     CommandShowEgyptian( char * ),
     CommandShowJacoby( char * ),
+    CommandShowKeith( char * ),
     CommandShowKleinman( char * ),
     CommandShowLang( char * ),
     CommandShowManualGUI( char * ),
@@ -1285,6 +1207,7 @@ extern void CommandAccept( char * ),
     CommandShowRollout( char * ),
     CommandShowRolls ( char * ),
     CommandShowScore( char * ),
+    CommandShowScoreSheet( char * ),
     CommandShowBearoff( char * ),
     CommandShowSeed( char * ),
     CommandShowSound( char * ),
@@ -1307,58 +1230,28 @@ extern void CommandAccept( char * ),
     CommandShowWarranty( char * ),
     CommandSwapPlayers ( char * ),
     CommandTake( char * ),
-    CommandTrainTD( char * ),
-    CommandXCopy ( char * );
+    CommandTrainTD( char * );
 
 
 extern int fTutor, fTutorCube, fTutorChequer, nTutorSkillCurrent;
 
-extern int fDisplayPanels;
-
 extern int GiveAdvice ( skilltype Skill );
 extern skilltype TutorSkill;
 extern int fTutorAnalysis;
 
 extern int EvalCmp ( const evalcontext *, const evalcontext *, const int);
 
-#ifndef HAVE_BASENAME
-extern char *
-basename ( const char* filename );
-#endif
+#define GNUBG_CHARSET "UTF-8"
 
-#ifndef HAVE_DIRNAME
-extern char *
-dirname ( char* filename );
-#endif
+extern char * locale_from_utf8 (const char * sz);
 
-#if USE_GTK
-#  if GTK_CHECK_VERSION(1,3,0) || defined (WIN32)
-#    define GNUBG_CHARSET "UTF-8"
-#  else
-#    define GNUBG_CHARSET "ISO-8859-1"
-#  endif
-#else
-#  define GNUBG_CHARSET "ISO-8859-1"
-#endif
-
-extern char *
-Convert ( const char* sz, 
-          const char* szSourceCharset, const char* szDestCharset );
+extern char * locale_to_utf8 (const char * sz);
 
 extern void
 OptimumRoll ( int anBoard[ 2 ][ 25 ], 
               const cubeinfo* pci, const evalcontext* pec,
               const int fBest, int anDice[ 2 ] );
 
-typedef struct _highlightcolour {
-  int   rgbs[3][3];
-  char* colourname;
-} highlightcolour;
-
-extern highlightcolour* HighlightColour, HighlightColourTable[];
-extern int HighlightIntensity;
-extern int* Highlightrgb;
-
 extern void
 SetMatchInfo( char **ppch, char* sz, char* szMessage );
 
@@ -1378,4 +1271,10 @@ EPC( int anBoard[ 2 ][ 25 ], float *arEPC, float *arMu, float *arSigma,
 extern char *
 ShowEPC( int anBoard[ 2 ][ 25 ] );
 
+extern void SetupLanguage(char *newLangCode);
+
+#define FONT_VERA "fonts/Vera.ttf"
+#define FONT_VERA_SERIF_BOLD "fonts/VeraSeBd.ttf"
+#define FONT_VERA_BOLD "fonts/VeraBd.ttf"
+
 #endif
