@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: bearoff.c,v 1.33 2004/04/29 18:45:24 thyssen Exp $
+ * $Id: bearoff.c,v 1.41.2.1 2006/11/06 23:29:34 c_anthon Exp $
  */
 
 #include "config.h"
@@ -28,6 +28,7 @@
 #include <assert.h>
 #include <errno.h>
 #include <math.h>
+#include <glib.h>
 
 #if HAVE_FCNTL_H
 #include <fcntl.h>
@@ -41,18 +42,14 @@
 #if HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
-#if HAVE_LIBGEN_H
-#include <libgen.h>
-#elif ! defined(HAVE_BASENAME) && ! defined (HAVE_DIRNAME )
-#include "simplelibgen.h"
-#endif
 
 #include "positionid.h"
 #include "eval.h"
 #include "bearoff.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "bearoffgammon.h"
 #include "path.h"
+#include "common.h"
 
 #if WIN32
 #define BINARY O_BINARY
@@ -122,7 +119,7 @@ setGammonProb(int anBoard[2][25], int bp0, int bp1, float* g0, float* g1)
     make[1] = (make[0] + gp->p1/(36.0*36.0));
     make[2] = (make[1] + gp->p2/(36.0*36.0*36.0));
     
-    *g1 = ((prob[1] / 65535.0) +
+    *g1 = (float)((prob[1] / 65535.0) +
 	   (1 - make[0]) * (prob[2] / 65535.0) +
 	   (1 - make[1]) * (prob[3] / 65535.0) +
 	   (1 - make[2]) * (prob[4] / 65535.0));
@@ -138,7 +135,7 @@ setGammonProb(int anBoard[2][25], int bp0, int bp1, float* g0, float* g1)
     make[1] = (make[0] + gp->p1/(36.0*36.0));
     make[2] = (make[1] + gp->p2/(36.0*36.0*36.0));
 
-    *g0 = ((prob[1] / 65535.0) * (1-make[0]) + (prob[2]/65535.0) * (1-make[1])
+    *g0 = (float)((prob[1] / 65535.0) * (1-make[0]) + (prob[2]/65535.0) * (1-make[1])
 	   + (prob[3]/65535.0) * (1-make[2]));
   }
 }  
@@ -160,7 +157,7 @@ AverageRolls ( const float arProb[ 32 ], float *ar ) {
 
 
   ar[ 0 ] = sx;
-  ar[ 1 ] = sqrt ( sx2 - sx *sx );
+  ar[ 1 ] = (float)sqrt ( sx2 - sx *sx );
 
 }
 
@@ -280,7 +277,7 @@ static void GenerateBearoff( unsigned char *p, int nId ) {
     }
 }
 
-static unsigned char *HeuristicDatabase( void (*pfProgress)( int ) ) {
+static unsigned char *HeuristicDatabase( void (*pfProgress)() ) {
 
     unsigned char *pm = malloc( 40 + 54264 * 64 );
     unsigned char *p = pm ? pm + 40 : NULL;
@@ -342,7 +339,7 @@ ReadTwoSidedBearoff ( bearoffcontext *pbc,
   if ( ! pc ) {
 
     if ( pbc->fInMemory )
-      pc = ((char *) pbc->p)+ 40 + 2 * iPos * k;
+      pc = ((unsigned char *) pbc->p) + 40 + 2 * iPos * k;
     else {
       lseek ( pbc->h, 40 + 2 * iPos * k, SEEK_SET );
       read ( pbc->h, ac, k * 2 );
@@ -493,7 +490,7 @@ ReadExactBearoff ( bearoffcontext *pbc,
     if ( ar )
       ar[ i ] = ul / storefactor - 2.0f;
     if ( aus )
-      aus[ i ] = ul >> 8;
+      aus[ i ] = (unsigned short)(ul >> 8);
 
   }
   
@@ -566,7 +563,7 @@ BearoffEvalTwoSided ( bearoffcontext *pbc,
     return -1;
 
   memset ( arOutput, 0, 5 * sizeof ( float ) );
-  arOutput[ OUTPUT_WIN ] = ar[ 0 ] / 2.0f + 0.5;
+  arOutput[ OUTPUT_WIN ] = ar[ 0 ] / 2.0f + 0.5f;
   
   return 0;
 
@@ -586,7 +583,7 @@ ReadHypergammon( bearoffcontext *pbc,
   const int x = 28;
 
   if ( pbc->fInMemory )
-    pc = ((char *) pbc->p)+ 40 + x * iPos;
+    pc = ((unsigned char *)pbc->p) + 40 + x * iPos;
   else {
     lseek ( pbc->h, 40 + x * iPos, SEEK_SET );
     read ( pbc->h, ac, x );
@@ -596,7 +593,7 @@ ReadHypergammon( bearoffcontext *pbc,
   if ( arOutput )
     for ( i = 0; i < NUM_OUTPUTS; ++i ) {
       us = pc[ 3 * i ] | ( pc[ 3 * i + 1 ] ) << 8 | ( pc[ 3 * i + 2 ] ) << 16;
-      arOutput[ i ] = us / 16777215.0;
+      arOutput[ i ] = us / 16777215.0f;
     }
 
   if ( arEquity )
@@ -736,7 +733,6 @@ ReadSconyers15x15( bearoffcontext *pbc,
   long lPos;
   unsigned char ac[ 16 ];
   float ar[ 4 ];
-  float *pr;
   long l;
   int i;
   int h = -1;
@@ -770,9 +766,9 @@ ReadSconyers15x15( bearoffcontext *pbc,
             pch2 = strdup( pch );
           
             if( pbc->szDir )
-              free( pbc->szDir );
+              g_free( pbc->szDir );
 
-            pbc->szDir = dirname( pch );
+            pbc->szDir = g_path_get_dirname( pch );
 
             free( pch );
             free( pch2 );
@@ -872,8 +868,12 @@ ReadSconyers15x15( bearoffcontext *pbc,
       ( ac[ 4 * i + 1 ] << 8 ) |
       ( ac[ 4 * i + 2 ] << 16 ) |
       ( ac[ 4 * i + 3 ] << 24 );
-    pr = (float *) &l;
-    ar[ i ] = *pr;
+    /* the commented code is strange and causes compiler warnings
+     * float* pr; 
+     * pr = (float *) &l; 
+     * ar[ i ] = *pr; 
+     * and is therefore replaced by */
+    ar[ i ] = (float)l;
   }
 
   /* Save equities */
@@ -924,6 +924,9 @@ BearoffEvalSconyers( bearoffcontext *pbc,
 extern int
 BearoffEval ( bearoffcontext *pbc, int anBoard[ 2 ][ 25 ], float arOutput[] ) {
 
+  if (!pbc)
+    return 0;
+
   switch ( pbc->bc ) {
   case BEAROFF_GNUBG:
 
@@ -1103,7 +1106,7 @@ BearoffDumpOneSided ( bearoffcontext *pbc, int anBoard[ 2 ][ 25 ], char *sz ) {
   int anPips[ 2 ];
   const float x = ( 2 * 3 + 3 * 4 + 4 * 5 + 4 * 6 + 6 * 7 +
               5* 8  + 4 * 9 + 2 * 10 + 2 * 11 + 1 * 12 + 
-              1 * 16 + 1 * 20 + 1 * 24 ) / 36.0;
+              1 * 16 + 1 * 20 + 1 * 24 ) / 36.0f;
 
 
   if ( BearoffDist ( pbc, nUs, aarProb[ 0 ], aarGammonProb[ 0 ], ar[ 0 ], 
@@ -1487,7 +1490,7 @@ BearoffAlloc( void ) {
 
 static bearoffcontext *
 BearoffInitSconyers( const char *szFilename, const char *szDir,
-                     const int bo, void *p ) {
+                     const int bo, void (*p)() ) {
 
   bearoffcontext *pbc;
   int i;
@@ -1537,7 +1540,7 @@ BearoffInitSconyers( const char *szFilename, const char *szDir,
     pbc->fCubeful = TRUE; /* yup, it has cubeful equities as well */
     pbc->hsdb = HS_15x15_ON_DVDS;
     pbc->nCurrentFile = -1;
-    pbc->pfDJ = p; /* pointer to the disk jockey function */
+    pbc->pfDJ = (diskjockeyfunc *)p; /* pointer to the disk jockey function */
     pbc->szDir = szDir ? strdup( szDir ) : NULL;
     pbc->szFilename = NULL;
     pbc->ph = NULL;
@@ -1574,7 +1577,7 @@ BearoffInitSconyers( const char *szFilename, const char *szDir,
 
 extern bearoffcontext *
 BearoffInit ( const char *szFilename, const char *szDir,
-              const int bo, void *p ) {
+              const int bo, void (*p)() ) {
 
   bearoffcontext *pbc;
   char sz[ 41 ];
@@ -1885,17 +1888,16 @@ BearoffInit ( const char *szFilename, const char *szDir,
 extern float
 fnd ( const float x, const float mu, const float sigma  ) {
 
-   const float epsilon = 1.0e-7;
-   const float PI = 3.14159265358979323846;
+   const float epsilon = 1.0e-7f;
 
    if ( sigma <= epsilon )
       /* dirac delta function */
-      return ( fabs ( mu - x ) < epsilon ) ? 1.0 : 0.0;
+      return ( fabs ( mu - x ) < epsilon ) ? 1.0f : 0.0f;
    else {
 
      float xm = ( x - mu ) / sigma;
 
-     return 1.0 / ( sigma * sqrt ( 2.0 * PI ) ) * exp ( - xm * xm / 2.0 );
+     return 1.0f / (float)(( sigma * sqrt ( 2.0 * PI ) ) * exp ( - xm * xm / 2.0 ));
 
    }
 
@@ -1937,7 +1939,7 @@ ReadBearoffOneSidedND ( bearoffcontext *pbc,
        if ( arProb )
          arProb[ i ] = r;
        if ( ausProb )
-         ausProb[ i ] = r * 65535.0f;
+         ausProb[ i ] = (unsigned short)(r * 65535.0f);
      }
      
 
@@ -1948,7 +1950,7 @@ ReadBearoffOneSidedND ( bearoffcontext *pbc,
       if ( arGammonProb )
         arGammonProb[ i ] = r;
       if ( ausGammonProb )
-        ausGammonProb[ i ] = r * 65535.0f;
+        ausGammonProb[ i ] = (unsigned short)(r * 65535.0f);
     }
   
   if ( ar )
@@ -2013,7 +2015,7 @@ CopyBytes ( unsigned short int aus[ 64 ],
             const unsigned int nzg,
             const unsigned int ioffg ) {
 
-  int i, j;
+  unsigned int i, j;
 
   i = 0;
   memset ( aus, 0, 64 * sizeof ( unsigned short int ) );
@@ -2083,9 +2085,9 @@ GetDistCompressed ( bearoffcontext *pbc, const unsigned int nPosID ) {
              "The bearoff file '%s' is likely to be corrupted.\n"
              "Please check that the MD5 sum is the same as documented "
              "in the GNU Backgammon manual.\n"
-             "Offset %ld, dist size %u (offset %u), "
+             "Offset %lu, dist size %u (offset %u), "
              "gammon dist size %u (offset %u)\n",
-             pbc->szFilename, iOffset, nz, ioff, nzg, ioffg );
+             pbc->szFilename, (unsigned long) iOffset, nz, ioff, nzg, ioffg );
     assert( FALSE );
   }
 
@@ -2289,6 +2291,3 @@ isBearoff ( bearoffcontext *pbc, int anBoard[ 2 ][ 25 ] ) {
     return FALSE;
 
 }
-
-
-
