@@ -18,30 +18,29 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* $Id: gtkcolour3d.c,v 1.18 2004/04/06 11:36:54 Superfly_Jon Exp $
+* $Id: gtkcolour3d.c,v 1.26 2006/09/11 22:59:40 Superfly_Jon Exp $
 */
 
 #include "config.h"
-#include <GL/gl.h>
-#include <GL/glu.h>
 #include <string.h>
 #include "inc3d.h"
 #include <gdk/gdkkeysyms.h>
+#include "gtkboard.h"
+#include <glib/gi18n.h>
 
-#if HAVE_GTKGLEXT
 #include <gtk/gtkgl.h>
-#else
-#include <gtkgl/gtkglarea.h>
-#endif
 
 #include "gtkcolour.h"
+#include "gtkwindows.h"
+
+extern void UpdatePreview(GtkWidget **ppw);
+static void RenderPreview(Material* pMat, unsigned char* buf);
 
 #define COLOUR_SEL_DIA( pcp ) GTK_COLOR_SELECTION_DIALOG( GTK_COLOUR_PICKER( \
 	pcp )->pwColourSel )
 #define COLOUR_SEL( pcp ) GTK_COLOR_SELECTION( COLOUR_SEL_DIA(pcp)->colorsel )
 
 GtkWidget *pcpAmbient, *pcpDiffuse, *pcpSpecular;
-GtkWidget *pwColourDialog3d;
 GtkAdjustment *padjShine, *padjOpacity;
 GtkWidget *psOpacity, *pOpacitylabel, *pTexturelabel, *pwPreview, *textureCombo;
 Material col3d;
@@ -70,12 +69,6 @@ int curDetail;
 
 unsigned char auch[PREVIEW_WIDTH * PREVIEW_HEIGHT * 3];
 
-extern void InitGL(BoardData *bd);
-extern void SetupMat(Material* pMat, float r, float g, float b, float dr, float dg, float db, float sr, float sg, float sb, int shin, float a);
-extern void setMaterial(Material* pMat);
-extern void UpdatePreview(GtkWidget **ppw);
-static void RenderPreview(Material* pMat, unsigned char* buf);
-
 extern GtkWidget *pwPrevBoard;
 
 int previewLightLevels[3];
@@ -117,7 +110,7 @@ static void Draw(Material* pMat)
 		char buf[100];
 		strcpy(buf, TEXTURE_PATH);
 		strcat(buf, pMat->textureInfo->file);
-		LoadTexture(&texture, buf, pMat->textureInfo->format);
+		LoadTexture(&texture, buf);
 
 		gluQuadricTexture(qobj, GL_TRUE);
 
@@ -188,7 +181,7 @@ void UpdateColourPreview(void *arg)
 		return;
 
 	if (useOpacity)
-		opacityValue = padjOpacity->value / 100.0f;
+		opacityValue = (float)padjOpacity->value / 100.0f;
 
 	gtk_colour_picker_get_colour(GTK_COLOUR_PICKER(pcpAmbient), ambient);
 	gtk_colour_picker_get_colour(GTK_COLOUR_PICKER(pcpDiffuse), diffuse);
@@ -221,8 +214,6 @@ void SetupColourPreview()
 	glLoadIdentity();
 }
 
-#if HAVE_GTKGLEXT
-
 GdkGLConfig *getglconfigSingle();
 
 GdkGLPixmap *glpixmap;
@@ -260,39 +251,6 @@ static void RenderPreview(Material* pMat, unsigned char* buf)
 	/*** OpenGL END ***/
 }
 
-#else
-
-extern GdkVisual *visual;
-
-void CreatePreview()
-{
-	SetupVisual();
-}
-
-static void RenderPreview(Material* pMat, unsigned char* buf)
-{
-	GdkGLPixmap *glpixmap;
-	GdkGLContext *glPixmapContext;
-
-	glPixmapContext = gdk_gl_context_new(visual);
-	glpixmap = gdk_gl_pixmap_new(visual, xppm);
-
-	if (!gdk_gl_pixmap_make_current(glpixmap, glPixmapContext))
-		return;
-
-	SetupColourPreview();
-	SetupLight();
-
-	Draw(pMat);
-
-	glReadPixels(0, 0, PREVIEW_WIDTH, PREVIEW_HEIGHT, GL_RGB, GL_UNSIGNED_BYTE, buf);
-
-	gdk_gl_pixmap_unref(glpixmap);
-	gdk_gl_context_unref(glPixmapContext);
-}
-
-#endif
-
 void TextureChange(GtkList *list, gpointer user_data)
 {
 	char* current = (char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(textureCombo)->entry));
@@ -369,92 +327,41 @@ void AddWidgets(GdkWindow* pixWind, GtkWidget *window)
 	gtk_table_attach_defaults(GTK_TABLE (table), pwPreview, 0, 2, 4, 5);
 }
 
-static gboolean CancelClicked( GtkWidget *pw, GdkEvent *pev, void* arg )
-{
-	gtk_window_set_modal( GTK_WINDOW( pwColourDialog3d ), FALSE );
-	gtk_widget_destroy( pwColourDialog3d );
-
-	gtk_main_quit();
-	return TRUE;
-}
-
 static gboolean OkClicked(GtkWidget *pw, UpdateDetails* pDetails)
-{
-	gtk_window_set_modal( GTK_WINDOW( pwColourDialog3d ), FALSE );
-	{	/* Apply new settings */
-		char* texStr;
-		GdkGC *gc;
+{	/* Apply new settings */
+	char* texStr;
+	GdkGC *gc;
 
-		/* Copy new settings to preview material */
-		*pDetails->pMat = col3d;
+	/* Copy new settings to preview material */
+	*pDetails->pMat = col3d;
 
-		if (useTexture)
+	if (useTexture)
+	{
+		texStr = (char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(textureCombo)->entry));
+
+		if (!strcmp(texStr, NO_TEXTURE_STRING))
+			col3d.textureInfo = 0;
+		else
 		{
-			texStr = (char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(textureCombo)->entry));
-
-			if (!strcmp(texStr, NO_TEXTURE_STRING))
-				col3d.textureInfo = 0;
-			else
-			{
-				BoardData *bd = BOARD(pwPrevBoard)->board_data;
-				ClearTextures(bd);
-				GetTextures(bd);
-			}
+			BoardData *bd = BOARD(pwPrevBoard)->board_data;
+			ClearTextures(&bd->bd3d);
+			GetTextures(&bd->bd3d, bd->rd);
 		}
-		gc = gdk_gc_new(pDetails->pixmap);
-		gdk_draw_rgb_image(pDetails->pixmap, gc, 0, 0, PREVIEW_WIDTH, PREVIEW_HEIGHT, GDK_RGB_DITHER_MAX,
-						  auch, PREVIEW_WIDTH * 3 );
-		gdk_gc_unref( gc );
-
-		gtk_widget_queue_draw(pDetails->preview);
-		UpdatePreview(0);
 	}
-	gtk_widget_destroy( pwColourDialog3d );
-	gtk_main_quit();
+	gc = gdk_gc_new(pDetails->pixmap);
+	gdk_draw_rgb_image(pDetails->pixmap, gc, 0, 0, PREVIEW_WIDTH, PREVIEW_HEIGHT, GDK_RGB_DITHER_MAX,
+						auch, PREVIEW_WIDTH * 3 );
+	gdk_gc_unref( gc );
+
+	gtk_widget_queue_draw(pDetails->preview);
+	UpdatePreview(0);
+
+	/* Close dialog */
+    gtk_widget_destroy(gtk_widget_get_toplevel(pw));
+
 	return TRUE;
 }
 
-GtkWidget* Create3dColourDialog(UpdateDetails* pDetails)
-{
-	GtkWidget *pwOK, *pwCancel, *pwButtons;
-	GtkAccelGroup *pag = gtk_accel_group_new();
-
-	pwColourDialog3d = gtk_dialog_new();
-
-	pwButtons = gtk_hbutton_box_new();
-	gtk_button_box_set_layout( GTK_BUTTON_BOX( pwButtons ),
-			       GTK_BUTTONBOX_SPREAD );
-	gtk_container_add( GTK_CONTAINER( GTK_DIALOG( pwColourDialog3d )->action_area ),
-		       pwButtons );
-	pwOK = gtk_button_new_with_label( _("OK") ),
-	gtk_container_add( GTK_CONTAINER( pwButtons ), pwOK );
-	pwCancel = gtk_button_new_with_label( _("Cancel") ),
-	gtk_container_add( GTK_CONTAINER( pwButtons ), pwCancel );
-
-	gtk_signal_connect(GTK_OBJECT(pwOK), "clicked", GTK_SIGNAL_FUNC(OkClicked), pDetails);
-	gtk_signal_connect(GTK_OBJECT(pwCancel), "clicked", GTK_SIGNAL_FUNC(CancelClicked), 0);	
-	gtk_signal_connect(GTK_OBJECT(pwColourDialog3d), "delete-event",
-			GTK_SIGNAL_FUNC(CancelClicked), 0 );
-	gtk_signal_connect(GTK_OBJECT(pwColourDialog3d), "realize",
-			GTK_SIGNAL_FUNC(UpdateColourPreview), 0 );
-
-#if GTK_CHECK_VERSION(1,3,15)
-	gtk_window_add_accel_group( GTK_WINDOW( pwColourDialog3d ), pag );
-#else
-	gtk_accel_group_attach( pag, GTK_OBJECT( pwColourDialog3d ) );
-#endif
-	gtk_widget_add_accelerator( pwCancel, "clicked", pag, GDK_Escape, 0, 0 );
-
-	gtk_window_set_title( GTK_WINDOW( pwColourDialog3d ), _("3d Colour selection") );
-
-	GTK_WIDGET_SET_FLAGS( pwOK, GTK_CAN_DEFAULT );
-	gtk_widget_grab_default( pwOK );
-
-	AddWidgets(pDetails->preview->window, GTK_DIALOG(pwColourDialog3d)->vbox);
-
-	return pwColourDialog3d;
-}
-
 void setCol(GtkColourPicker* pCP, float val[4])
 {
 	double dval[4];
@@ -465,15 +372,20 @@ void setCol(GtkColourPicker* pCP, float val[4])
 	gtk_colour_picker_set_colour(pCP, dval);
 }
 
-void SetColour3d(GtkWidget *pw, UpdateDetails* pDetails)
+static void UpdateColour3d(GtkWidget *pw, UpdateDetails* pDetails)
 {
+	GtkWidget* pwColourDialog3d = GTKCreateDialog(_("3d Colour selection"), DT_QUESTION, 
+		pDetails->preview, DIALOG_FLAG_MODAL, GTK_SIGNAL_FUNC(OkClicked), pDetails);
+
+	gtk_signal_connect(GTK_OBJECT(pwColourDialog3d), "realize", GTK_SIGNAL_FUNC(UpdateColourPreview), 0 );
+
+	AddWidgets(pDetails->preview->window, DialogArea(pwColourDialog3d, DA_MAIN));
+
 	col3d = *pDetails->pMat;
 
 	/* Avoid updating preview */
 	bUpdate = FALSE;
 
-	Create3dColourDialog(pDetails);
-
 	/* Setup widgets */
 	setCol(GTK_COLOUR_PICKER(pcpAmbient), col3d.ambientColour);
 	setCol(GTK_COLOUR_PICKER(pcpDiffuse), col3d.diffuseColour);
@@ -520,8 +432,6 @@ void SetColour3d(GtkWidget *pw, UpdateDetails* pDetails)
 	memcpy(&cancelValue, &col3d, sizeof(Material));
 
 	/* show dialog */
-	gtk_window_set_modal( GTK_WINDOW( pwColourDialog3d ), TRUE );
-	gtk_window_set_transient_for(GTK_WINDOW(pwColourDialog3d), GTK_WINDOW(dialogParent));
 	gtk_widget_show_all( pwColourDialog3d );
 
 	if (!useOpacity)
@@ -596,7 +506,7 @@ GtkWidget* gtk_colour_picker_new3d(Material* pMat, int opacity, int texture)
 	details[curDetail].texture = texture;
 
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-				   GTK_SIGNAL_FUNC(SetColour3d), &details[curDetail]);
+				   GTK_SIGNAL_FUNC(UpdateColour3d), &details[curDetail]);
 
 	UpdatePreviewBar(pMat, pixmap);
 	curDetail++;
