@@ -18,31 +18,32 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* $Id: shadow.c,v 1.5 2004/03/31 09:51:57 Superfly_Jon Exp $
+* $Id: shadow.c,v 1.9 2006/09/21 22:24:45 Superfly_Jon Exp $
 */
 
 #include "config.h"
+
 #include <assert.h>
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
-#include "matrix.h"
-#include <GL/gl.h>
-#include "inc3d.h"
+
 #include "shadow.h"
+#include "model.h"
+#include "matrix.h"
 
 int midStencilVal;
 
-extern void GenerateShadowVolume(Occluder* pOcc, float olight[4]);
-extern void GenerateShadowEdges(Occluder* pOcc);
-
-void shadowInit(BoardData* bd)
+void shadowInit(BoardData3d *bd3d, renderdata *prd)
 {
 	int i;
 	int stencilBits;
 
+	/* Darkness as percentage of ambient light */
+	prd->dimness = ((prd->lightLevels[1] / 100.0f) * (100 - prd->shadowDarkness)) / 100;
+
 	for (i = 0; i < NUM_OCC; i++)
-		bd->Occluders[i].handle = 0;
+		bd3d->Occluders[i].handle = 0;
 
 	/* Check the stencil buffer is present */
 	glGetIntegerv(GL_STENCIL_BITS, &stencilBits);
@@ -55,18 +56,6 @@ void shadowInit(BoardData* bd)
 	glClearStencil(midStencilVal);
 }
 
-void moveToOcc(Occluder* pOcc)
-{
-	glTranslatef(pOcc->trans[0], pOcc->trans[1], pOcc->trans[2]);
-
-	if (pOcc->rotator)
-	{
-		glRotatef(pOcc->rot[0], 0, 1, 0);
-		glRotatef(pOcc->rot[1], 1, 0, 0);
-		glRotatef(pOcc->rot[2], 0, 0, 1);
-	}
-}
-
 void draw_shadow_volume_edges(Occluder* pOcc)
 {
 	if (pOcc->show)
@@ -94,7 +83,7 @@ void draw_shadow_volume_extruded_edges(Occluder* pOcc, float light_position[4],
 	}
 }
 
-void draw_shadow_volume_to_stencil(BoardData* bd)
+void draw_shadow_volume_to_stencil(BoardData3d* bd3d)
 {
 	int i;
 
@@ -107,19 +96,19 @@ void draw_shadow_volume_to_stencil(BoardData* bd)
 	glDepthMask(GL_FALSE);
 
 	/* Z-pass approach */
-	glStencilFunc(GL_ALWAYS, midStencilVal, ~0);
+	glStencilFunc(GL_ALWAYS, midStencilVal, (GLuint)~0);
 
 	glCullFace(GL_FRONT);
 	glStencilOp(GL_KEEP, GL_KEEP, GL_DECR);
 
 	for (i = 0; i < NUM_OCC; i++)
-		draw_shadow_volume_extruded_edges(&bd->Occluders[i], bd->shadow_light_position, GL_QUADS);
+		draw_shadow_volume_extruded_edges(&bd3d->Occluders[i], bd3d->shadow_light_position, GL_QUADS);
 
 	glCullFace(GL_BACK);
 	glStencilOp(GL_KEEP, GL_KEEP, GL_INCR);
 
 	for (i = 0; i < NUM_OCC; i++)
-		draw_shadow_volume_extruded_edges(&bd->Occluders[i], bd->shadow_light_position, GL_QUADS);
+		draw_shadow_volume_extruded_edges(&bd3d->Occluders[i], bd3d->shadow_light_position, GL_QUADS);
 
 	/* Enable colour buffer, lighting and depth buffer */
 	glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
@@ -127,34 +116,36 @@ void draw_shadow_volume_to_stencil(BoardData* bd)
 	glDepthMask(GL_TRUE);
 }
 
-void shadowDisplay(void (*drawScene)(BoardData*), BoardData* bd)
+void shadowDisplay(void (*drawScene)(BoardData *, BoardData3d *, renderdata *), BoardData* bd)
 {
 	/* Pass 1: Draw model, ambient light only (some diffuse to vary shadow darkness) */
 	float zero[4] = {0,0,0,0};
-	float d1[4] = {bd->rd->dimness, bd->rd->dimness, bd->rd->dimness, bd->rd->dimness};
+	float d1[4];
 	float specular[4];
 	float diffuse[4];
+	renderdata *prd = bd->rd;
 
 	glGetLightfv(GL_LIGHT0, GL_DIFFUSE, diffuse);
+	d1[0] = d1[1] = d1[2] = d1[3] = prd->dimness;
 	glLightfv(GL_LIGHT0, GL_DIFFUSE, d1);
 	/* No specular light */
 	glGetLightfv(GL_LIGHT0, GL_SPECULAR, specular);
 	glLightfv(GL_LIGHT0, GL_SPECULAR, zero);
 
-	drawScene(bd);
+	drawScene(bd, &bd->bd3d, prd);
 
 	glLightfv(GL_LIGHT0, GL_SPECULAR, specular);
 	glLightfv(GL_LIGHT0, GL_DIFFUSE, diffuse);
 
 	/* Create shadow volume in stencil buffer */
 	glEnable(GL_STENCIL_TEST);
-	draw_shadow_volume_to_stencil(bd);
+	draw_shadow_volume_to_stencil(&bd->bd3d);
 
 	/* Pass 2: Redraw model, full light in non-shadowed areas */
-	glStencilFunc(GL_EQUAL, midStencilVal, ~0);
+	glStencilFunc(GL_EQUAL, midStencilVal, (GLuint)~0);
 	glStencilOp(GL_KEEP, GL_KEEP, GL_KEEP);
 
-	drawScene(bd);
+	drawScene(bd, &bd->bd3d, prd);
 
 	glDisable(GL_STENCIL_TEST);
 }
