@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dice.c,v 1.38 2004/05/03 13:21:49 thyssen Exp $
+ * $Id: dice.c,v 1.47 2006/09/21 22:24:05 Superfly_Jon Exp $
  */
 
 #include "config.h"
@@ -53,6 +53,7 @@
 #include <unistd.h>
 #endif
 
+#if HAVE_SOCKETS
 #ifndef WIN32
 #include <errno.h>
 #include <sys/types.h>
@@ -106,13 +107,18 @@
 #define ESTALE                  WSAESTALE
 #define EREMOTE                 WSAEREMOTE
 #endif /* #ifndef WIN32 */
+#endif /* #if HAVE_SOCKETS */
+
+#if HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
 
 #include "backgammon.h"
 #include "dice.h"
 #include "md5.h"
 #include "mt19937ar.h"
 #include "isaac.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "external.h"
 #include "path.h"
 
@@ -511,7 +517,7 @@ PrintRNGSeedMP( mpz_t n ) {
 
 }
 
-#endif /* HAVE_LIBGMP */
+#else
 
 static void
 PrintRNGSeedNormal( int n ) {
@@ -519,6 +525,8 @@ PrintRNGSeedNormal( int n ) {
   outputf( _("The current seed is %d.\n"), n );
 
 }
+#endif /* HAVE_LIBGMP */
+
 
 extern void PrintRNGSeed( const rng rngx, void *p ) {
 
@@ -758,7 +766,6 @@ CloseRNG( const rng rngx, void *p ) {
     ;
 
   }
-
 }
 
 
@@ -908,7 +915,7 @@ getDiceRandomDotOrg ( void ) {
     strcpy( szHostname, "www.random.org:80" );
 
     if ( ( h = ExternalSocket( &psa, &cb, szHostname ) ) < 0 ) {
-      outputerr ( szHostname );
+      SockErr ( szHostname );
       return -1;
     }
 
@@ -919,15 +926,15 @@ getDiceRandomDotOrg ( void ) {
 #else
     if ( ( connect( h, psa, cb ) ) < 0 ) {
 #endif /* WIN32 */
-      outputerr( szHostname );
+      SockErr( szHostname );
       return -1;
     }
 
     /* read next set of numbers */
 
     if ( ExternalWrite( h, szHTTP, strlen ( szHTTP ) + 1 ) < 0 ) {
-      outputerr( szHTTP );
-      close( h );
+      SockErr( szHTTP );
+      closesocket( h );
       return -1;
     }
 
@@ -940,21 +947,15 @@ getDiceRandomDotOrg ( void ) {
 #else
 	if ( ! ( nBytesRead = read( h, acBuf, sizeof ( acBuf ) ) ) ) {
 #endif
-      outputerr( "reading data" );
-      close( h );
+      SockErr( "reading data" );
+      closesocket( h );
       return -1;
     }
 
     /* close socket */
-
-#ifdef WIN32
-    closesocket( (SOCKET) h ); 
-#else
-    close ( h );
-#endif
+    closesocket ( h );
 
     /* parse string */
-
     outputl ( _("Done." ) );
     outputx ();
 
@@ -1120,13 +1121,7 @@ extern int RollDice( int anDice[ 2 ], const rng rngx, void *p ) {
 extern int UserRNGOpen( void *p, char *sz ) {
 
   char *error;
-#if __GNUC__
-  char szCWD[ strlen( sz ) + 3 ];
-#elif HAVE_ALLOCA
-  char *szCWD = alloca( strlen( szOrig ) + 3 );
-#else
-  char szCWD[ 4096 ];
-#endif
+  VARIABLE_ARRAY(char, szCWD, strlen( sz ) + 3)
   rngcontext *rngctx = (rngcontext *) p;
 
   /* 
@@ -1227,7 +1222,8 @@ ReadDiceFile( rngcontext *rngctx ) {
   unsigned char uch;
   int n;
 
-  while ( 1 ) {
+uglyloop:
+  {
   
     n = read( rngctx->hDice, &uch, 1 );
 
@@ -1244,6 +1240,7 @@ ReadDiceFile( rngcontext *rngctx ) {
       return (uch - '0');
 
   }
+  goto uglyloop;	/* This logic should be reconsidered */
 
   return -1;
 
