@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: drawboard.c,v 1.33 2004/02/09 13:02:30 uid68519 Exp $
+ * $Id: drawboard.c,v 1.37.2.1 2006/11/06 23:29:34 c_anthon Exp $
  */
 
 #include "config.h"
@@ -30,7 +30,7 @@
 
 #include "drawboard.h"
 #include "positionid.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 int fClockwise = FALSE; /* Player 1 moves clockwise */
 
@@ -59,8 +59,8 @@ static char *DrawBoardStd( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
 
     char *pch = sz, *pchIn;
     int x, y, an[ 2 ][ 25 ], cOffO = nChequers, cOffX = nChequers;
-    static char achX[ 16 ] = "     X6789ABCDEF",
-        achO[ 16 ] = "     O6789ABCDEF";
+    static char achX[ 17 ] = "     X6789ABCDEF",
+        achO[ 17 ] = "     O6789ABCDEF";
 
     for( x = 0; x < 25; x++ ) {
         cOffO -= anBoard[ 0 ][ x ];
@@ -69,7 +69,7 @@ static char *DrawBoardStd( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
     
     strcpy( pch, _ (" GNU Backgammon  Position ID: ") );
 
-    pch += 30;
+    pch = strchr ( pch, 0 );
 
     if( fRoll )
         strcpy( pch, PositionID( anBoard ) );
@@ -180,7 +180,7 @@ static char *DrawBoardStd( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
     
     *pch++ = fRoll ? 'v' : '^';
     strcpy( pch, _("|                  |BAR|                  |     ") );
-    pch += 48;
+    pch = strchr ( pch, 0 );
     
     if( asz[ 3 ] )
         for( pchIn = asz[ 3 ]; *pchIn; pchIn++ )
@@ -304,8 +304,8 @@ static char *DrawBoardCls( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
 
     char *pch = sz, *pchIn;
     int x, y, an[ 2 ][ 25 ], cOffO = nChequers, cOffX = nChequers;
-    static char achX[ 16 ] = "     X6789ABCDEF",
-        achO[ 16 ] = "     O6789ABCDEF";
+    static char achX[ 17 ] = "     X6789ABCDEF",
+        achO[ 17 ] = "     O6789ABCDEF";
 
     for( x = 0; x < 25; x++ ) {
         cOffO -= anBoard[ 0 ][ x ];
@@ -314,7 +314,7 @@ static char *DrawBoardCls( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
     
     strcpy( pch, _("    GNU Backgammon  Position ID: ") );
 
-    pch += 33;
+    pch = strchr ( pch, 0 );
 
     if( fRoll )
         strcpy( pch, PositionID( anBoard ) );
@@ -419,7 +419,7 @@ static char *DrawBoardCls( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
     *pch++ = '\n';
     
     strcpy( pch, _("    |                  |BAR|                  |") );
-    pch += 47;
+    pch = strchr ( pch, 0 );
     *pch++ = fRoll ? 'v' : '^';
     *pch++ = ' ';   
     
@@ -522,18 +522,20 @@ extern char *DrawBoard( char *sz, int anBoard[ 2 ][ 25 ], int fRoll,
 
     return ( DrawBoardCls( sz, anBoard, fRoll, asz, 
                            szMatchID, nChequers ) ) ;   
-};
+}
 
 static char *FormatPoint( char *pch, int n ) {
 
     assert( n >= 0 );
     
+    /*don't translate 'off' and 'bar' as these may be used in UserCommand at a later
+     * point */
     if( !n ) {
-        strcpy( pch, _("off") );
-        return pch + strlen(_("off") );
+        strcpy( pch, ("off") );
+        return pch + strlen(("off") );
     } else if( n == 25 ) {
-        strcpy( pch, _("bar") );
-        return pch + strlen(_("bar") );
+        strcpy( pch, ("bar") );
+        return pch + strlen(("bar") );
     } else if( n > 9 )
         *pch++ = n / 10 + '0';
 
