@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: drawboard.h,v 1.9 2001/10/29 15:13:18 gtw Exp $
+ * $Id: drawboard.h,v 1.11 2003/04/04 20:41:59 thyssen Exp $
  */
 
 #ifndef _DRAWBOARD_H_
@@ -25,7 +25,7 @@
 extern int fClockwise; /* Player 1 moves clockwise */
 
 extern char *DrawBoard( char *pch, int anBoard[ 2 ][ 25 ], int fRoll,
-                        char *asz[] );
+                        char *asz[], char *szMatchID, int nChequers );
 /* Fill the buffer pch with a representation of the move anMove, assuming
    the board looks like anBoard.  pch must have room for 28 characters plus
    a trailing 0 (consider the move `bar/24* 23/22* 21/20* 19/18*'). */
@@ -39,7 +39,7 @@ extern char *FIBSBoard( char *pch, int anBoard[ 2 ][ 25 ], int fRoll,
 			char *szPlayer, char *szOpp, int nMatchTo,
 			int nScore, int nOpponent, int nDice0, int nDice1,
 			int nCube, int fCubeOwner, int fDoubled, int fTurn,
-			int fCrawford );
+			int fCrawford, int nChequers );
 /* Read a FIBS "boardstyle 3" description from pch. */
 extern int ParseFIBSBoard( char *pch, int anBoard[ 2 ][ 25 ],
 			   char *szPlayer, char *szOpp, int *pnMatchTo,
