@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: eval.h,v 1.131 2006/04/12 23:45:50 c_anthon Exp $
+ * $Id: eval.h,v 1.133 2006/09/21 22:24:05 Superfly_Jon Exp $
  */
 
 #ifndef _EVAL_H_
@@ -42,8 +42,8 @@
 #define MAX_ROLLOUT_CUBEINFO 16
 #define NUM_ROLLOUT_OUTPUTS 7
 
-#define BETA_HIDDEN 0.1
-#define BETA_OUTPUT 1.0
+#define BETA_HIDDEN 0.1f
+#define BETA_OUTPUT 1.0f
 
 #define OUTPUT_WIN 0
 #define OUTPUT_WINGAMMON 1
@@ -421,6 +421,9 @@ PipCount( int anBoard[ 2 ][ 25 ], int anPips[ 2 ] );
 extern int 
 ThorpCount( int anBoard[ 2 ][ 25 ], int *pnLeader, int *pnTrailer );
 
+extern int
+KeithCount(int anBoard[2][25], int *pnL, int *pnT);
+
 extern int 
 DumpPosition( int anBoard[ 2 ][ 25 ], char *szOutput,
               const evalcontext* pec, cubeinfo* pci, int fOutputMWC,
