@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: external.c,v 1.48 2004/10/26 19:11:35 oysteijo Exp $
+ * $Id: external.c,v 1.51 2006/09/21 22:24:05 Superfly_Jon Exp $
  */
 
 #include "config.h"
@@ -104,7 +104,7 @@
 #include "drawboard.h"
 #include "external.h"
 #include "rollout.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 #if HAVE_SOCKETS
 /* Stuff for the yacc/lex parser */
@@ -597,7 +597,8 @@ extern void CommandExternal( char *sz ) {
 	return;
     }
 
-    do {
+listenloop:
+	{
 
       if( ( h = ExternalSocket( &psa, &cb, sz ) ) < 0 ) {
 	SockErr( sz );
@@ -651,8 +652,6 @@ extern void CommandExternal( char *sz ) {
       outputf( _("Accepted connection from %s.\n"), 
                  inet_ntoa( saRemote.sin_addr ) );
 
-      PushLocale( "C" );
-
       while( !ExternalRead( hPeer, szCommand, sizeof( szCommand ) ) ) {
 
         if ( ! ( pec = ExtParse( szCommand ) ) ) {
@@ -688,12 +687,8 @@ extern void CommandExternal( char *sz ) {
         }
 
       }
-
-
-      PopLocale();
-
       closesocket( hPeer );
-
-    } while ( 1 );
+    }
+	goto listenloop;
 #endif
 }
