@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: formatgs.h,v 1.1 2003/08/30 18:10:01 thyssen Exp $
+ * $Id: formatgs.h,v 1.2 2006/10/04 12:28:39 c_anthon Exp $
  */
 
 #ifndef _FORMATGS_H_
@@ -33,7 +33,7 @@ enum _formatgs {
   FORMATGS_OVERALL };
 
 extern GList *
-formatGS( const statcontext *psc, const matchstate *pms,
+formatGS( const statcontext *psc, const int nMatchTo,
           const int fIsMatch, const enum _formatgs fg );
 
 extern void
