@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gnubgmodule.c,v 1.48 2005/02/10 10:31:12 Superfly_Jon Exp $
+ * $Id: gnubgmodule.c,v 1.53.2.2 2006/11/10 11:34:40 c_anthon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -37,7 +37,6 @@
 
 #include <stdio.h>
 #include <glib.h>
-#include "i18n.h"
 #include "backgammon.h"
 #include "eval.h"
 #include "matchequity.h"
@@ -45,9 +44,9 @@
 #include "positionid.h"
 #include "analysis.h"
 #include "md5.h"
+#include <glib/gi18n.h>
 
-#undef IGNORE	// Ignore msdev define
-#define IGNORE __attribute__ ((unused))
+#define UNUSED_PARAM __attribute__ ((unused))
 
 static PyObject *
 BoardToPy( int anBoard[ 2 ][ 25 ] )
@@ -348,18 +347,21 @@ PyToEvalContext( PyObject *p, evalcontext *pec ) {
 
 
 static PyObject *
-PythonCubeInfo(PyObject* self IGNORE, PyObject* args) {
+PythonCubeInfo(PyObject* self UNUSED_PARAM, PyObject* args) {
 
   cubeinfo ci;
   int nCube = ms.nCube;
   int fCubeOwner = ms.fCubeOwner;
   int fMove = ms.fMove;
   int nMatchTo = ms.nMatchTo;
-  int anScore[ 2 ] = { ms.anScore[ 0 ], ms.anScore[ 1 ] };
+  int anScore[ 2 ];
   int fCrawford = ms.fCrawford;
   int fJacoby = ms.fJacoby;
   int fBeavers = ms.cBeavers;
   bgvariation bgv = ms.bgv;
+  anScore[ 0 ] = ms.anScore[ 0 ];
+  anScore[ 1 ] = ms.anScore[ 1 ];
+
 
   if ( ! PyArg_ParseTuple( args, "|iiii(ii)iiii:cubeinfo", 
                            &nCube, &fCubeOwner, &fMove, &nMatchTo, 
@@ -378,7 +380,7 @@ PythonCubeInfo(PyObject* self IGNORE, PyObject* args) {
 
 
 static PyObject *
-PythonNextTurn( PyObject *self IGNORE, PyObject *args ) {
+PythonNextTurn( PyObject *self UNUSED_PARAM, PyObject *args ) {
 
   fNextTurn = TRUE;
   while( fNextTurn ) {
@@ -392,7 +394,7 @@ PythonNextTurn( PyObject *self IGNORE, PyObject *args ) {
 
 
 static PyObject *
-PythonEvalContext( PyObject* self IGNORE, PyObject *args ) {
+PythonEvalContext( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   evalcontext ec;
   int fCubeful = 0, nPlies = 0, nReduced = 0, fDeterministic = 1;
@@ -415,7 +417,7 @@ PythonEvalContext( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonCommand( PyObject* self IGNORE, PyObject *args ) {
+PythonCommand( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   char *pch;
   char *sz;
@@ -447,7 +449,7 @@ PythonCommand( PyObject* self IGNORE, PyObject *args ) {
 
 
 static PyObject *
-PythonBoard( PyObject* self IGNORE, PyObject *args ) {
+PythonBoard( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   if ( ! PyArg_ParseTuple( args, ":board" ) )
     return NULL;
@@ -462,7 +464,7 @@ PythonBoard( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonLuckRating( PyObject* self IGNORE, PyObject *args ) {
+PythonLuckRating( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   float r;
   if ( ! PyArg_ParseTuple( args, "f", &r ) )
@@ -473,7 +475,7 @@ PythonLuckRating( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonErrorRating( PyObject* self IGNORE, PyObject *args ) {
+PythonErrorRating( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   float r;
   if ( ! PyArg_ParseTuple( args, "f", &r ) )
@@ -484,7 +486,7 @@ PythonErrorRating( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonEvaluate( PyObject* self IGNORE, PyObject *args ) {
+PythonEvaluate( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyBoard = NULL;
   PyObject *pyCubeInfo = NULL;
@@ -528,7 +530,7 @@ PythonEvaluate( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonEvaluateCubeful( PyObject* self IGNORE, PyObject *args ) {
+PythonEvaluateCubeful( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyBoard = NULL;
   PyObject *pyCubeInfo = NULL;
@@ -579,7 +581,7 @@ PythonEvaluateCubeful( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonFindBestMove( PyObject* self IGNORE, PyObject *args ) {
+PythonFindBestMove( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyDice = NULL;
   PyObject *pyBoard = NULL;
@@ -683,7 +685,7 @@ METPre( float aar[ MAXSCORE ][ MAXSCORE ], const int n ) {
 
 
 static PyObject *
-PythonMET( PyObject* self IGNORE, PyObject *args ) {
+PythonMET( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   int n = ms.nMatchTo ? ms.nMatchTo : MAXSCORE;
   int i;
@@ -727,7 +729,7 @@ PythonMET( PyObject* self IGNORE, PyObject *args ) {
 
 
 static PyObject *
-PythonEq2mwc( PyObject* self IGNORE, PyObject *args ) {
+PythonEq2mwc( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyCubeInfo = NULL;
   float r = 0.0f;
@@ -777,7 +779,7 @@ extern char* GameAsString()
 		int move = 1;
 		for (plMove = plStart->plNext; plMove->p; plMove = plMove->plNext)
 		{
-			char playerStr[3] = ".AB";
+			char playerStr[4] = ".AB";
 			int player;
 			moverecord* pmr = plMove->p;
 			char* moveString = GetMoveString(pmr, &player);
@@ -807,9 +809,10 @@ extern char* GameAsString()
 }
 
 extern PyObject *
-PythonMatchChecksum( PyObject* self IGNORE, PyObject *args )
+PythonMatchChecksum( PyObject* self UNUSED_PARAM, PyObject *args )
 {
-	unsigned char auch[16], auchHex[33];
+	unsigned char auch[16];
+	char auchHex[33];
 	int i;
 	// Work out md5 checksum
 	char* gameStr = GameAsString();
@@ -823,7 +826,7 @@ PythonMatchChecksum( PyObject* self IGNORE, PyObject *args )
 }
 
 static PyObject *
-PythonMwc2eq( PyObject* self IGNORE, PyObject *args ) {
+PythonMwc2eq( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyCubeInfo = NULL;
   float r = 0.0f;
@@ -842,7 +845,7 @@ PythonMwc2eq( PyObject* self IGNORE, PyObject *args ) {
 
 
 static PyObject *
-PythonPositionID( PyObject* self IGNORE, PyObject *args ) {
+PythonPositionID( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyBoard = NULL;
   int anBoard[ 2 ][ 25 ];
@@ -860,7 +863,7 @@ PythonPositionID( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonPositionFromID( PyObject* self IGNORE, PyObject *args )
+PythonPositionFromID( PyObject* self UNUSED_PARAM, PyObject *args )
 {
   char* sz = NULL;
   int anBoard[ 2 ][ 25 ];
@@ -884,7 +887,7 @@ PythonPositionFromID( PyObject* self IGNORE, PyObject *args )
 
 
 static PyObject *
-PythonPositionKey( PyObject* self IGNORE, PyObject *args ) {
+PythonPositionKey( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   PyObject *pyBoard = NULL;
   int anBoard[ 2 ][ 25 ];
@@ -911,7 +914,7 @@ PythonPositionKey( PyObject* self IGNORE, PyObject *args ) {
 }
 
 static PyObject *
-PythonPositionFromKey( PyObject* self IGNORE, PyObject *args ) {
+PythonPositionFromKey( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   int anBoard[ 2 ][ 25 ];
   int i;
@@ -946,7 +949,7 @@ PythonPositionFromKey( PyObject* self IGNORE, PyObject *args ) {
 
 
 static PyObject *
-PythonPositionBearoff( PyObject* self IGNORE, PyObject *args )
+PythonPositionBearoff( PyObject* self UNUSED_PARAM, PyObject *args )
 {
   PyObject *pyBoard = NULL;
   int nChequers = 15;
@@ -966,7 +969,7 @@ PythonPositionBearoff( PyObject* self IGNORE, PyObject *args )
 }
 
 static PyObject *
-PythonPositionFromBearoff( PyObject* self IGNORE, PyObject *args ) {
+PythonPositionFromBearoff( PyObject* self UNUSED_PARAM, PyObject *args ) {
 
   int anBoard[ 25 ];
   int iPos = 0;
@@ -1549,7 +1552,7 @@ PyGameStats(const statcontext* sc, const int fIsMatch, const int nMatchTo)
     int side;
     for(side = 0; side < 2; ++side) {
       PyObject* d =
-	Py_BuildValue("{s:f,s:f,s:f,s:f,s:f}",
+	Py_BuildValue("{s:f,s:f,s:f,s:f}",
 		      "luck", sc->arLuck[side][0],
 		      "luck-cost", sc->arLuck[side][1], 
                       "actual-result", sc->arActualResult[side],
@@ -1976,7 +1979,7 @@ addProperty(PyObject* dict, const char* name, const char* val)
 }
   
 static PyObject*
-PythonMatch(PyObject* self IGNORE, PyObject* args, PyObject* keywds)
+PythonMatch(PyObject* self UNUSED_PARAM, PyObject* args, PyObject* keywds)
 {
   /* take match info from first game */
   const list* firstGame = lMatch.plNext->p;
@@ -2015,8 +2018,6 @@ PythonMatch(PyObject* self IGNORE, PyObject* args, PyObject* keywds)
     return 0;
   }
 
-  PushLocale("C");
-
   if (g->i != 0)
   {
       PyErr_SetString(PyExc_StandardError, "First game missing from match");
@@ -2151,14 +2152,12 @@ PythonMatch(PyObject* self IGNORE, PyObject* args, PyObject* keywds)
 /* 		     PyInt_FromLong(SGF_ROLLOUT_VER)); */
   }
 
-  PopLocale();
-
   return matchDict;
 }
 
 
 static PyObject*
-PythonNavigate(PyObject* self IGNORE, PyObject* args, PyObject* keywds)
+PythonNavigate(PyObject* self UNUSED_PARAM, PyObject* args, PyObject* keywds)
 {
   int nextRecord = INT_MIN;
   int nextGame = INT_MIN;
