@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkchequer.c,v 1.66 2006/02/24 17:41:47 Superfly_Jon Exp $
+ * $Id: gtkchequer.c,v 1.72 2006/09/13 21:55:07 c_anthon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -41,16 +41,14 @@
 #include "gtkboard.h"
 #include "gtkgame.h"
 #include "gtkchequer.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "gtktempmap.h"
+#include "gtkwindows.h"
 #include "progress.h"
 #include "format.h"
 
-#if USE_GTK2
-extern moverecord *pmrCurAnn;;
+extern moverecord *pmrCurAnn;
 int showMoveListDetail = 1;
-#endif
-
 extern void MoveListCreate(hintdata *phd);
 extern void MoveListUpdate(const hintdata *phd);
 extern GList* MoveListGetSelectionList(const hintdata *phd);
@@ -91,6 +89,7 @@ static void MoveListRolloutClicked(GtkWidget *pw, hintdata *phd)
   }
 	MoveListFreeSelectionList(plSelList);
 
+	GTKSetCurrentParent(pw);
   RolloutProgressStart( &ci, c, NULL, &rcRollout, asz, &p );
 
   if ( fAction )
@@ -199,6 +198,7 @@ static void MoveListTempMapClicked( GtkWidget *pw, hintdata *phd )
   }
 	MoveListFreeSelectionList(plSelList);
 
+	GTKSetCurrentParent(pw);
   GTKShowTempMap( ams, c, ( const gchar** ) asz, TRUE );
 
   g_free( ams );
@@ -297,23 +297,21 @@ MoveListEvalPly ( GtkWidget *pw, hintdata *phd )
 static void
 MoveListEvalSettings ( GtkWidget *pw, void *unused )
 {
+	GTKSetCurrentParent(pw);
   SetEvaluation ( NULL, 0, NULL );
 
-#if GTK_CHECK_VERSION(2,0,0)
   /* bring the dialog holding this button to the top */
   gtk_window_present ( GTK_WINDOW ( gtk_widget_get_toplevel( pw ) ) );
-#endif
 }
 
 static void
 MoveListRolloutSettings ( GtkWidget *pw, void *unused )
 {
-  SetRollouts ( NULL, 0, NULL );
+	GTKSetCurrentParent(pw);
+	SetRollouts ( NULL, 0, NULL );
 
-#if GTK_CHECK_VERSION(2,0,0)
   /* bring the dialog holding this button to the top */
   gtk_window_present ( GTK_WINDOW ( gtk_widget_get_toplevel( pw ) ) );
-#endif
 }
 
 typedef int ( *cfunc )( const void *, const void * );
@@ -398,14 +396,9 @@ MoveListMove ( GtkWidget *pw, hintdata *phd )
 static void
 MoveListDetailsClicked( GtkWidget *pw, hintdata *phd )
 {
-#if USE_GTK2
 	 showMoveListDetail = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pw));
 	 /* Reshow list */
 	 SetAnnotation(pmrCurAnn);
-#else
-  /* show hint dialog */
-  GTKHint( phd->pml, phd->piHighlight ? *phd->piHighlight : -1 );
-#endif
 }
 
 GtkWidget *pwDetails;
@@ -430,12 +423,7 @@ CreateMoveListTools ( hintdata *phd )
   GtkTooltips *pt = gtk_tooltips_new ();
 
   pwDetails = 
-#if USE_GTK2
     phd->fDetails ? NULL : gtk_toggle_button_new_with_label( _("Details") );
-#else
-    phd->fDetails ? NULL : gtk_button_new_with_label( _("Details") );
-#endif
-
   phd->pwRollout = pwRollout;
   phd->pwRolloutSettings = pwRolloutSettings;
   phd->pwEval = pwEval;
@@ -521,11 +509,8 @@ CreateMoveListTools ( hintdata *phd )
   gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( pwMWC ),
                                  fOutputMWC );
 
-#if USE_GTK2
   if (pwDetails)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pwDetails), showMoveListDetail);
-#endif
-
   /* signals */
 
   gtk_signal_connect( GTK_OBJECT( pwRollout ), "clicked",
@@ -589,7 +574,6 @@ CreateMoveListTools ( hintdata *phd )
   return pwTools;
 }
 
-#if USE_GTK2
 void HintDoubleClick(GtkTreeView        *treeview,
                        GtkTreePath        *path,
                        GtkTreeViewColumn  *col,
@@ -617,36 +601,6 @@ void HintSelect(GtkTreeSelection *selection, hintdata *phd)
 		}
 	}
 }
-#else
-static void HintSelect( GtkWidget *pw, int y, int x, GdkEventButton *peb,
-			hintdata *phd )
-{
-	int c = g_list_length(MoveListGetSelectionList(phd));
-	CheckHintButtons( phd );
-
-    /* Double clicking a row makes that move. */
-    if( c == 1 && peb && peb->type == GDK_2BUTTON_PRESS && 
-        phd->fButtonsValid ) {
-      gtk_button_clicked( GTK_BUTTON( phd->pwMove ) );
-      return;
-    }
-
-    /* show moves */
-
-    if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON ( phd->pwShow ) ) ) {
-      switch ( c ) {
-      case 0:
-      case 1:
-        ShowMove ( phd, c );
-        break;
-
-      default:
-        ShowMove ( phd, FALSE );
-        break;
-      }
-    }
-}
-#endif
 
 static void MoveListCopy(GtkWidget *pw, hintdata *phd)
 {
