@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkoptions.c,v 1.30 2006/09/21 22:24:05 Superfly_Jon Exp $
+ * $Id: gtkoptions.c,v 1.30.2.1 2006/11/06 23:29:34 c_anthon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -79,7 +79,6 @@ typedef struct _optionswidget {
 
   GtkWidget *pwCheat, *pwCheatRollBox, *apwCheatRoll[ 2 ];
   GtkWidget *pwGotoFirstGame, *pwGameListStyles;
-  GtkWidget *pwLangMenu;
 
   GtkWidget *pwSconyers15x15DVD;
   GtkWidget *pwSconyers15x15Disk;
@@ -167,22 +166,6 @@ static void ToggleAnimation( GtkWidget *pw, GtkWidget *pwSpeed ) {
                                   GTK_TOGGLE_BUTTON( pw ) ) );
 }
 
-static char *aaszLang[][ 2 ] = {
-    { N_("System default"), "system" },
-    { N_("Czech"),	    "cs_CZ" },
-    { N_("Danish"),	    "da_DA" },
-    { N_("English (UK)"),   "en_UK" },
-    { N_("English (US)"),   "en_US" },
-    { N_("French"),	    "fr_FR" },
-    { N_("German"),	    "de_DE" },
-    { N_("Icelandic"),      "is_IS" },
-    { N_("Italian"),	    "it_IT" },
-    { N_("Japanese"),	    "ja_JP" },
-    { N_("Russian"),	    "ru_RU" },
-    { N_("Turkish"),	    "tr_TR" },
-    { NULL, NULL }
-};
-
 static char *aszTutor[] = {
 	N_("Doubtful"), N_("Bad"), N_("Very bad"), NULL
 };
@@ -1463,40 +1446,6 @@ static GtkWidget *OptionsPages( optionswidget *pow ) {
                             "colours depending on their analysis"),
                           NULL );
 
-    /* language preference */
-
-    pwhbox = gtk_hbox_new( FALSE, 4 );
-    gtk_box_pack_start( GTK_BOX( pwvbox ), pwhbox, FALSE, FALSE, 0 );
-    gtk_box_pack_start( GTK_BOX( pwhbox ), gtk_label_new( _("Language:") ),
-			FALSE, FALSE, 0 );
-    pow->pwLangMenu = gtk_option_menu_new();
-    gtk_box_pack_start( GTK_BOX( pwhbox ), pow->pwLangMenu, FALSE, FALSE, 0 );
-    gtk_container_set_border_width( GTK_CONTAINER( pow->pwLangMenu ), 1 );
-    pwm = gtk_menu_new();
-
-    {
-	int iCurrentSettingPredifined = FALSE;
-
-	for ( i = 0; aaszLang[ i ][ 0 ]; ++i ) {
-	    gtk_menu_append( GTK_MENU( pwm ),
-			     pw = gtk_menu_item_new_with_label( 
-				    gettext( aaszLang[ i ][ 0 ] ) ) );
-	    if ( ! strcmp( szLang, aaszLang[ i ][ 1 ] ) )
-		iCurrentSettingPredifined = TRUE;
-	}
-	if ( ! iCurrentSettingPredifined ) {
-	    char* sz = NULL;
-	    sz = g_strdup_printf( _("User defined: %s"), szLang );
-	    gtk_menu_append( GTK_MENU( pwm ),
-			     pw = gtk_menu_item_new_with_label( 
-				    sz ) );
-	    g_free( sz );
-	}
-    }
-
-    gtk_widget_show_all( pwm );
-    gtk_option_menu_set_menu( GTK_OPTION_MENU( pow->pwLangMenu ), pwm );
-
     /* return notebook */
 
     return pwn;    
@@ -1831,17 +1780,6 @@ static void OptionsOK( GtkWidget *pw, optionswidget *pow ){
   CHECKUPDATE( pow->pwGotoFirstGame, fGotoFirstGame, "set gotofirstgame %s" )
   CHECKUPDATE( pow->pwGameListStyles, fStyledGamelist, "set styledgamelist %s" )
       
-  /* language preference */
-
-  n = gtk_option_menu_get_history( GTK_OPTION_MENU( pow->pwLangMenu ) );
-  if ( n >= 0 && ( n < sizeof( aaszLang ) / sizeof( aaszLang[0] ) ) &&
-       aaszLang[1]) {
-    if (aaszLang[ n ][ 1 ] &&  strcmp( szLang, aaszLang[ n ][ 1 ] ) ) {
-      sprintf( sz, "set lang %s", aaszLang[ n ][ 1 ] );
-      UserCommand( sz );
-    }
-  }
-
   /* Destroy widget on exit */
   gtk_widget_destroy( gtk_widget_get_toplevel( pw ) );
   
@@ -1934,13 +1872,6 @@ OptionsSet( optionswidget *pow) {
   gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pow->pwGameListStyles ),
                                 fStyledGamelist );
 
-  /* language preference */
-
-  for ( i = 0; aaszLang[ i ][ 0 ]; ++i )
-    if ( ! strcmp( szLang, aaszLang[ i ][ 1 ] ) )
-      break;
-  gtk_option_menu_set_history( GTK_OPTION_MENU( pow->pwLangMenu ), i );
-
   /* bearoff options */
 
   gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pow->pwSconyers15x15DVD ),
