@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrolls.c,v 1.10 2005/02/14 13:17:13 Superfly_Jon Exp $
+ * $Id: gtkrolls.c,v 1.16 2006/09/21 22:24:05 Superfly_Jon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -38,10 +38,9 @@
 #include "gtkrolls.h"
 #include "gtkgame.h"
 #include "drawboard.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "format.h"
-
-#if USE_GTK2
+#include "gtkwindows.h"
 
 typedef struct _rollswidget {
 
@@ -168,8 +167,8 @@ sort_func ( GtkTreeModel *model,
   gtk_tree_model_get ( model, a, 2, &sz0, -1 );
   gtk_tree_model_get ( model, b, 2, &sz1, -1 );
 
-  r0 = atof ( sz0 );
-  r1 = atof ( sz1 );
+  r0 = (float)atof ( sz0 );
+  r1 = (float)atof ( sz1 );
 
   if ( r0 < r1 )
     return -1;
@@ -275,7 +274,7 @@ static void DepthChanged ( GtkRange *pr, rollswidget *prw )
 		return;
 	}
 
-	n = gtk_range_get_value(pr);
+	n = (int)gtk_range_get_value(pr);
 	if (n == prw->nDepth)
 		return;
 
@@ -340,12 +339,9 @@ static gint RollsClose(GtkWidget *widget, GdkEvent *event, rollswidget *prw)
 		return FALSE;
 }
 
-#endif /* USE_GTK2 */
-
 extern void
 GTKShowRolls ( const gint nDepth, evalcontext *pec, matchstate *pms ) {
 
-#if USE_GTK2
 
   GtkWidget *vbox, *hbox;
   GtkAdjustment *padj;
@@ -354,7 +350,7 @@ GTKShowRolls ( const gint nDepth, evalcontext *pec, matchstate *pms ) {
   rollswidget *prw = g_malloc ( sizeof ( rollswidget ) );
 
   prw->closing = FALSE;
-  prw->pDialog = GTKCreateDialog( _("Distribution of rolls"), DT_INFO, NULL, NULL );
+  prw->pDialog = GTKCreateDialog( _("Distribution of rolls"), DT_INFO, NULL, DIALOG_FLAG_MODAL, NULL, NULL );
 
   n = ( nDepth < 1 ) ? 1 : nDepth;
 
@@ -410,29 +406,17 @@ GTKShowRolls ( const gint nDepth, evalcontext *pec, matchstate *pms ) {
 
   /* tree  */
 
-  if( ( prw->ptv = RollsTree ( n, pec, pms ) ) ) {
+  if( ( prw->ptv = RollsTree ( n, pec, pms ) ) != 0 ) {
       gtk_container_add ( GTK_CONTAINER ( prw->psw ), prw->ptv );
       prw->nDepth = n;
   }
   
-  /* modality */
-
   gtk_window_set_default_size( GTK_WINDOW( prw->pDialog ), 560, 400 ); 
-  gtk_window_set_modal( GTK_WINDOW( prw->pDialog ), TRUE );
-  gtk_window_set_transient_for( GTK_WINDOW( prw->pDialog ),
-                                GTK_WINDOW( pwMain ) );
-
   gtk_widget_show_all( prw->pDialog );
-
   gtk_signal_connect( GTK_OBJECT( prw->pDialog ), "delete_event",
-                      GTK_SIGNAL_FUNC(RollsClose), prw );
-  gtk_signal_connect( GTK_OBJECT( prw->pDialog ), "destroy",
-                      GTK_SIGNAL_FUNC(gtk_main_quit), NULL );
+                      GTK_SIGNAL_FUNC(RollsClose), prw );	/* In case closed mid calculation */
 
   GTKDisallowStdin();
   gtk_main();
   GTKAllowStdin();
-  
-#endif
-
 }
