@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtktheory.c,v 1.31 2006/02/24 17:41:47 Superfly_Jon Exp $
+ * $Id: gtktheory.c,v 1.36 2006/09/21 22:24:05 Superfly_Jon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -27,7 +27,6 @@
 #include <alloca.h>
 #endif
 
-#define GTK_ENABLE_BROKEN /* for GtkText */
 #include <gtk/gtk.h>
 
 #include <stdio.h>
@@ -38,8 +37,9 @@
 #include "eval.h"
 #include "gtkgame.h"
 #include "gtktheory.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "matchequity.h"
+#include "gtkwindows.h"
 
 #define MAXPLY 4
 
@@ -185,7 +185,7 @@ TheoryGetValues ( theorywidget *ptw, cubeinfo *pci,
 
   for ( i = 0; i < 2; i++ )
     for ( j = 0; j < 2; j++ )
-      aarRates[ i ][ j ] = 0.01f * ptw->aapwRates[ i ][ j ]->value;
+      aarRates[ i ][ j ] = 0.01f * (float)ptw->aapwRates[ i ][ j ]->value;
 
 
   /* money game or match play */
@@ -194,8 +194,8 @@ TheoryGetValues ( theorywidget *ptw, cubeinfo *pci,
 
     /* match play */
 
-    int n0 = ptw->apwScoreAway[ 0 ]->value;
-    int n1 = ptw->apwScoreAway[ 1 ]->value;
+    int n0 = (int)ptw->apwScoreAway[ 0 ]->value;
+    int n1 = (int)ptw->apwScoreAway[ 1 ]->value;
 
     pci->nMatchTo = ( n1 > n0 ) ? n1 : n0;
 
@@ -254,8 +254,9 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
   int i, j, k;
   int afAutoRedouble[ 2 ];
   int afDead[ 2 ];
-  GdkFont *pf;
   gchar *pch;
+  GtkTextBuffer *buffer;
+  GtkTextIter iter;
 
   const char *aszMoneyPointLabel[] = {
     N_ ("Take Point (TP)"),
@@ -451,18 +452,9 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
    * Update gammon price widgets
    */
 
-#if WIN32
-  /* Windows fonts come out smaller than you ask for, for some reason... */
-  pf = gdk_font_load( "-b&h-lucidatypewriter-medium-r-normal-sans-14-"
-                      "*-*-*-m-*-*-*" );
-#else
-  pf = gdk_font_load( "-b&h-lucidatypewriter-medium-r-normal-sans-12-"
-                      "*-*-*-m-*-*-*" );
-#endif
-
-  gtk_text_freeze( GTK_TEXT( ptw->pwGammonPrice ) );
-
-  gtk_editable_delete_text( GTK_EDITABLE( ptw->pwGammonPrice ), 0, -1 );
+  buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(ptw->pwGammonPrice));
+  gtk_text_buffer_set_text(buffer, "", -1);
+  gtk_text_buffer_get_end_iter (buffer, &iter);
 
   if ( ci.nMatchTo ) {
 
@@ -471,12 +463,11 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
                            ci.nMatchTo - ci.anScore[ 1 ],
                            ci.nCube );
 
-    gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
-                     pch, -1 );
+    gtk_text_buffer_insert( buffer, &iter, pch, -1);
     
     g_free( pch );
 
-    gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
+    gtk_text_buffer_insert( buffer, &iter,
                      _("Player                          Gammon   BG\n"), -1 );
     
 
@@ -488,8 +479,7 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
                              0.5f * ( ci.arGammonPrice[ 2 + j ] + 
                                       ci.arGammonPrice[ j ] ) );
       
-      gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
-                       pch, -1 );
+      gtk_text_buffer_insert( buffer, &iter, pch, -1);
       
       g_free( pch );
       
@@ -498,7 +488,7 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
   }
   else {
 
-    gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
+    gtk_text_buffer_insert( buffer, &iter,
                      _("Gammon values for money game:\n\n"), -1 );
 
     for ( i = 0; i < 2; ++i ) {
@@ -508,8 +498,7 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
                                "Gammon   BG\n"),
                              i ? _("Doubled cube") : _("Centered cube") );
 
-      gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
-                       pch, -1 );
+      gtk_text_buffer_insert( buffer, &iter, pch, -1);
     
       g_free( pch );
 
@@ -525,25 +514,19 @@ TheoryUpdated ( GtkWidget *pw, theorywidget *ptw ) {
                                0.5f * ( ci.arGammonPrice[ 2 + j ] + 
                                         ci.arGammonPrice[ j ] ) );
 
-        gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
-                         pch, -1 );
+        gtk_text_buffer_insert( buffer, &iter, pch, -1);
     
         g_free( pch );
 
       }
 
-      gtk_text_insert( GTK_TEXT( ptw->pwGammonPrice ), pf, NULL, NULL,
+    gtk_text_buffer_insert( buffer, &iter,
                        "\n", -1 );
 
     }
 
   }
 
-  gtk_text_thaw( GTK_TEXT( ptw->pwGammonPrice ) );
-
-
-
-
 }
 
 static void GraphExpose( GtkWidget *pwGraph, GdkEventExpose *pev,
@@ -574,7 +557,7 @@ static void GraphExpose( GtkWidget *pwGraph, GdkEventExpose *pev,
     }
 
     for( i = 0; i < 3; i++ )
-	ax[ i ] = x + cx * ptw->aar[ iPlayer ][ i ];
+	ax[ i ] = (int)(x + cx * ptw->aar[ iPlayer ][ i ]);
 
     gtk_paint_box( pwGraph->style, pwGraph->window, GTK_STATE_NORMAL,
 		   GTK_SHADOW_IN, NULL, pwGraph, "doubling-window",
@@ -663,6 +646,7 @@ GTKShowTheory ( const int fActivePage ) {
   int i, j;
   char sz[ 256 ];
   int *pi;
+  PangoFontDescription *font_desc;
 
   static char *aszTitles[] = {
     NULL,
@@ -679,8 +663,8 @@ GTKShowTheory ( const int fActivePage ) {
 
   /* create dialog */
 
-  pwDialog = GTKCreateDialog ( _("GNU Backgammon - Theory"), DT_INFO,
-                            NULL, NULL );
+  pwDialog = GTKCreateDialog( _("GNU Backgammon - Theory"), DT_INFO,
+		NULL, DIALOG_FLAG_MODAL, NULL, NULL );
 
   gtk_window_set_default_size( GTK_WINDOW( pwDialog ), 660, 300 );
 
@@ -814,15 +798,15 @@ GTKShowTheory ( const int fActivePage ) {
   pwx = gtk_vbox_new ( FALSE, 4 );
   gtk_container_add ( GTK_CONTAINER ( pwFrame ), pwx );
 
-  gtk_box_pack_start( GTK_BOX( pwx ), pwz = gtk_label_new( miCurrent.szName ),
+  gtk_box_pack_start( GTK_BOX( pwx ), pwz = gtk_label_new( (char*) miCurrent.szName ),
                       FALSE, FALSE, 0 );
   gtk_misc_set_alignment( GTK_MISC( pwz ), 0, 0.5 );
   gtk_box_pack_start( GTK_BOX( pwx ),
-                      pwz = gtk_label_new( miCurrent.szFileName ),
+                      pwz = gtk_label_new( (char*) miCurrent.szFileName ),
                       FALSE, FALSE, 0 );
   gtk_misc_set_alignment( GTK_MISC( pwz ), 0, 0.5 );
   gtk_box_pack_start( GTK_BOX( pwx ),
-                      pwz = gtk_label_new( miCurrent.szDescription ),
+                      pwz = gtk_label_new( (char*) miCurrent.szDescription ),
                       FALSE, FALSE, 0 );
   gtk_misc_set_alignment( GTK_MISC( pwz ), 0, 0.5 );
   
@@ -1001,8 +985,13 @@ GTKShowTheory ( const int fActivePage ) {
 
   pwVBox = gtk_vbox_new ( FALSE, 0 );
 
-  ptw->pwGammonPrice = gtk_text_new( NULL, NULL );
-  gtk_text_set_line_wrap ( GTK_TEXT( ptw->pwGammonPrice ), FALSE );
+  ptw->pwGammonPrice = gtk_text_view_new();
+  gtk_text_view_set_editable(GTK_TEXT_VIEW(ptw->pwGammonPrice), FALSE);
+
+  font_desc = pango_font_description_from_string ("Monospace");
+  gtk_widget_modify_font (ptw->pwGammonPrice, font_desc);
+  pango_font_description_free (font_desc);
+  gtk_text_view_set_wrap_mode ( GTK_TEXT_VIEW( ptw->pwGammonPrice ), GTK_WRAP_NONE );
 
   gtk_container_add ( GTK_CONTAINER( pwVBox ), ptw->pwGammonPrice );
 
@@ -1012,24 +1001,15 @@ GTKShowTheory ( const int fActivePage ) {
 
   /* show dialog */
 
-  gtk_window_set_modal( GTK_WINDOW( pwDialog ), TRUE );
-  gtk_window_set_transient_for( GTK_WINDOW( pwDialog ),
-                                GTK_WINDOW( pwMain ) );
-  gtk_signal_connect( GTK_OBJECT( pwDialog ), "destroy",
-                      GTK_SIGNAL_FUNC( gtk_main_quit ), NULL );
-
   gtk_widget_show_all( pwDialog );
 
   ResetTheory ( NULL, ptw );
-  
   TheoryUpdated ( NULL, ptw );
   
-  gtk_notebook_set_page ( GTK_NOTEBOOK ( pwNotebook ),
-                          fActivePage ? 2 /* prices */ : 0 /* market */ );
+  gtk_notebook_set_page ( GTK_NOTEBOOK ( pwNotebook ), fActivePage ? 2 /* prices */ : 0 /* market */ );
 
   GTKDisallowStdin();
   gtk_main();
   GTKAllowStdin();
-
 }
 
