@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: html.c,v 1.167 2006/04/07 12:20:23 c_anthon Exp $
+ * $Id: html.c,v 1.172 2006/10/04 12:28:39 c_anthon Exp $
  */
 
 #include "config.h"
@@ -31,8 +31,8 @@
 #include <unistd.h>
 #endif
 #include <stdlib.h>
+#include <glib.h>
 
-#define USES_badSkill
 #include "analysis.h"
 #include "backgammon.h"
 #include "drawboard.h"
@@ -45,13 +45,7 @@
 #include "path.h"
 #include "formatgs.h"
 
-#if HAVE_LIBGEN_H
-#include <libgen.h>
-#elif ! defined(HAVE_BASENAME) && ! defined (HAVE_DIRNAME )
-#include "simplelibgen.h"
-#endif
-
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 typedef enum _stylesheetclass {
   CLASS_MOVETABLE,
@@ -173,7 +167,7 @@ WriteStyleSheet ( FILE *pf, const htmlexportcss hecss ) {
 
     fputs( "\n"
            "/* CSS Stylesheet for " VERSION_STRING " */\n"
-           "/* $Id: html.c,v 1.167 2006/04/07 12:20:23 c_anthon Exp $ */\n",
+           "/* $Id: html.c,v 1.172 2006/10/04 12:28:39 c_anthon Exp $ */\n",
            pf );
 
     fputs( _("/* This file is distributed as a part of the "
@@ -1853,7 +1847,7 @@ HTMLEpilogue ( FILE *pf, const matchstate *pms, char *aszLinks[ 4 ],
   int fFirst;
   int i;
 
-  const char szVersion[] = "$Revision: 1.167 $";
+  const char szVersion[] = "$Revision: 1.172 $";
   int iMajor, iMinor;
 
   iMajor = atoi ( strchr ( szVersion, ' ' ) );
@@ -1933,7 +1927,7 @@ HTMLEpilogueComment ( FILE *pf ) {
 
   time_t t;
 
-  const char szVersion[] = "$Revision: 1.167 $";
+  const char szVersion[] = "$Revision: 1.172 $";
   int iMajor, iMinor;
   char *pc;
 
@@ -2916,7 +2910,7 @@ static void HTMLDumpStatcontext ( FILE *pf, const statcontext *psc,
 
   if( psc->fMoves ) {
 
-    GList *list = formatGS( psc, pms, fIsMatch, FORMATGS_CHEQUER );
+    GList *list = formatGS( psc, pms->nMatchTo, fIsMatch, FORMATGS_CHEQUER );
     GList *pl;
 
     printStatTableHeader ( pf, hecss, _("Checker play statistics") );
@@ -2938,7 +2932,7 @@ static void HTMLDumpStatcontext ( FILE *pf, const statcontext *psc,
 
   if( psc->fDice ) {
 
-    GList *list = formatGS( psc, pms, fIsMatch, FORMATGS_LUCK );
+    GList *list = formatGS( psc, pms->nMatchTo, fIsMatch, FORMATGS_LUCK );
     GList *pl;
 
     printStatTableHeader ( pf, hecss, 
@@ -2961,7 +2955,7 @@ static void HTMLDumpStatcontext ( FILE *pf, const statcontext *psc,
 
   if( psc->fCube ) {
 
-    GList *list = formatGS( psc, pms, fIsMatch, FORMATGS_CUBE );
+    GList *list = formatGS( psc, pms->nMatchTo, fIsMatch, FORMATGS_CUBE );
     GList *pl;
 
     printStatTableHeader ( pf, hecss, 
@@ -2984,7 +2978,7 @@ static void HTMLDumpStatcontext ( FILE *pf, const statcontext *psc,
 
   {
     
-    GList *list = formatGS( psc, pms, fIsMatch, FORMATGS_OVERALL );
+    GList *list = formatGS( psc, pms->nMatchTo, fIsMatch, FORMATGS_OVERALL );
     GList *pl;
     
     printStatTableHeader ( pf, hecss, 
@@ -3468,13 +3462,12 @@ getMoveNumber ( const list *plGame, const void *p ) {
 static FILE *
 OpenCSS( const char *sz ) {
 
-  char *pch = strdup( sz );
-  char *pchBase = dirname( pch );
-  char *pchCSS;
+  gchar *pch = g_strdup( sz );
+  gchar *pchBase = g_path_get_dirname( pch );
+  gchar *pchCSS;
   FILE *pf;
   
-  sprintf( pchCSS = (char *) malloc( strlen( pchBase ) + 20 ),
-           "%s%c%s", pchBase, DIR_SEPARATOR, "gnubg.css" );
+  pchCSS = g_build_filename(pchBase, "gnubg.css", NULL );
 
   if ( !access( pchCSS, R_OK ) ) {
     /* file exists */
@@ -3486,9 +3479,9 @@ OpenCSS( const char *sz ) {
     outputerr( pchCSS );
   }
 
-  free( pch );
-  free( pchBase );
-  free( pchCSS );
+  g_free( pch );
+  g_free( pchBase );
+  g_free( pchCSS );
 
   return pf;
 
@@ -3557,21 +3550,6 @@ extern void CommandExportGameHtml( char *sz ) {
  *   Caller must free returned pointer if not NULL
  * 
  */
-#ifdef WIN32
-#define DIR_SEPARATOR  '\\'
-#define DIR_SEPARATOR_S  "\\"
-#else
-#define DIR_SEPARATOR  '/'
-#define DIR_SEPARATOR_S  "/"
-#endif
-
-static char *
-get_basename (const char *filename) 
-{ 
-  char *p1 = strrchr (filename, DIR_SEPARATOR); 
-  return p1 ? p1 + 1 : (char *) filename;
-} 
-
 
 extern char *
 HTMLFilename ( const char *szBase, const int iGame ) {
@@ -3634,23 +3612,23 @@ extern void CommandExportMatchHtml( char *sz ) {
 
       szCurrent = HTMLFilename ( sz, i );
 	  filenames[0] = HTMLFilename ( sz, 0 );
-      aszLinks[ 0 ] = get_basename ( filenames[ 0 ] );
+      aszLinks[ 0 ] = g_path_get_basename ( filenames[ 0 ] );
 	  filenames[ 1 ] = aszLinks[ 1 ] = NULL;
 	  if (i > 0) {
 		filenames[ 1 ] = HTMLFilename ( sz, i - 1 );
-		aszLinks[ 1 ]  = get_basename ( filenames[ 1 ] );
+		aszLinks[ 1 ]  = g_path_get_basename ( filenames[ 1 ] );
 	  }
 		
 	  filenames[ 2 ] = aszLinks[ 2 ] = NULL;
 	  if (i < nGames - 1) {
 		filenames[ 2 ] = HTMLFilename ( sz, i + 1 );
-		aszLinks[ 2 ]  = get_basename ( filenames[ 2 ] );
+		aszLinks[ 2 ]  = g_path_get_basename ( filenames[ 2 ] );
 	  }
 
 
 	  
 	  filenames[ 3 ] = HTMLFilename ( sz, nGames - 1 );
-	  aszLinks[ 3 ] = get_basename ( filenames[ 3 ] );
+	  aszLinks[ 3 ] = g_path_get_basename ( filenames[ 3 ] );
       if ( !i ) {
 
         if ( ! confirmOverwrite ( sz, fConfirmSave ) ) {
