@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: makebearoff.c,v 1.33 2005/02/21 23:23:08 jsegrave Exp $
+ * $Id: makebearoff.c,v 1.36 2006/09/24 06:22:20 kaoru Exp $
  */
 
 #include "config.h"
@@ -26,14 +26,17 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#include <sys/types.h>
 #include <math.h>
 #include <errno.h>
 #include <stdarg.h>
 #include "eval.h"
 #include "positionid.h"
 #include "getopt.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "bearoff.h"
 
 #if WIN32
@@ -652,11 +655,10 @@ generate_os ( const int nOS, const int fHeader,
 #if WIN32
   HINSTANCE hInstance = (HINSTANCE) GetModuleHandle(NULL);
   HWND hwndPB;
+  INITCOMMONCONTROLSEX InitCtrlEx;
   if( hdlg != NULL)
     ShowWindow(hdlg, SW_SHOW);
 
-  INITCOMMONCONTROLSEX InitCtrlEx;
-
   InitCtrlEx.dwSize = sizeof(INITCOMMONCONTROLSEX);
   InitCtrlEx.dwICC  = ICC_PROGRESS_CLASS;
   InitCommonControlsEx(&InitCtrlEx);
@@ -929,11 +931,10 @@ generate_nd ( const int nPoints,const int nHashSize, const int fHeader,
 #if WIN32
   HINSTANCE hInstance = (HINSTANCE) GetModuleHandle(NULL);
   HWND hwndPB;
+  INITCOMMONCONTROLSEX InitCtrlEx;
   if( hdlg != NULL)
     ShowWindow(hdlg, SW_SHOW);
 
-  INITCOMMONCONTROLSEX InitCtrlEx;
-
   InitCtrlEx.dwSize = sizeof(INITCOMMONCONTROLSEX);
   InitCtrlEx.dwICC  = ICC_PROGRESS_CLASS;
   InitCommonControlsEx(&InitCtrlEx);
@@ -1284,11 +1285,10 @@ generate_ts ( const int nTSP, const int nTSC,
 #if WIN32
   HINSTANCE hInstance = (HINSTANCE) GetModuleHandle(NULL);
   HWND hwndPB;
+  INITCOMMONCONTROLSEX InitCtrlEx;
   if( hdlg != NULL)
     ShowWindow(hdlg, SW_SHOW);
 
-  INITCOMMONCONTROLSEX InitCtrlEx;
-
   InitCtrlEx.dwSize = sizeof(INITCOMMONCONTROLSEX);
   InitCtrlEx.dwICC  = ICC_PROGRESS_CLASS;
   InitCommonControlsEx(&InitCtrlEx);
@@ -1501,9 +1501,9 @@ usage ( char *arg0 ) {
 static void
 version ( void ) {
 #ifndef WIN32
-  printf ( "makebearoff $Revision: 1.33 $\n" );
+  printf ( "makebearoff $Revision: 1.36 $\n" );
 #else
-  MessageBox( NULL, "makebearoff $Revision: 1.33 $\n", "Makebearoff", MB_OK );
+  MessageBox( NULL, "makebearoff $Revision: 1.36 $\n", "Makebearoff", MB_OK );
 #endif
 }
 
@@ -1647,7 +1647,7 @@ extern int main( int argc, char **argv ) {
     dlgprintf( 123, "%d", nHashSize);
     dlgprintf( 124, "%s", szOldBearoff ? "yes" : "no");
     dlgprintf(130, "Generating one-sided bearoff database. Please wait." );
-    dlgprintf(131, "makebearoff $Revision: 1.33 $" );
+    dlgprintf(131, "makebearoff $Revision: 1.36 $" );
 #else
     fprintf ( stderr, 
               _("One-sided database:\n"
@@ -1775,7 +1775,7 @@ extern int main( int argc, char **argv ) {
     dlgprintf(125, "" );
     dlgprintf(126, "" );
     dlgprintf(130, "Generating two-sided bearoff database. Please wait." );
-    dlgprintf(131, "makebearoff $Revision: 1.33 $" );
+    dlgprintf(131, "makebearoff $Revision: 1.36 $" );
 #else 
     fprintf ( stderr,
               _("Two-sided database:\n"
