@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: progress.c,v 1.20 2005/05/08 12:34:56 Superfly_Jon Exp $
+ * $Id: progress.c,v 1.25 2006/09/21 22:24:06 Superfly_Jon Exp $
  */
 
 #include "config.h"
@@ -36,12 +36,13 @@
 #include "rollout.h"
 #include "progress.h"
 #include "backgammon.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "format.h"
 #include "time.h"
 
 #if USE_GTK
 #include "gtkgame.h"
+#include "gtkwindows.h"
 #endif /* USE_GTK */
 
 
@@ -136,7 +137,7 @@ estimatedTimeLeft( const time_t tStart, const int iGame, const int nTrials,
 
   /* estimate time left */
 
-  return ( ( nAlt - iAlt - 1 ) + ( nTrials - iGame - 1 ) * nAlt ) * tpert;
+  return (time_t)(( ( nAlt - iAlt - 1 ) + ( nTrials - iGame - 1 ) * nAlt ) * tpert);
 
 }
 
@@ -165,7 +166,7 @@ formatDelta( const time_t t ) {
 static float
 estimatedSE( const float rSE, const int iGame, const int nTrials ) {
 
-  return rSE * sqrt( ( 1.0f * iGame ) / ( 1.0f * ( nTrials - 1 ) ) );
+  return rSE * (float)sqrt( ( 1.0 * iGame ) / ( 1.0 * ( nTrials - 1 ) ) );
 
 
 }
@@ -715,8 +716,7 @@ GTKViewRolloutStatistics(GtkWidget *widget, gpointer data){
 
   /* Create dialog */
 
-  pwDialog = GTKCreateDialog ( _("Rollout statistics"), DT_INFO, NULL, NULL );
-
+  pwDialog = GTKCreateDialog ( _("Rollout statistics"), DT_INFO, prp->pwRolloutDialog, DIALOG_FLAG_MODAL, NULL, NULL );
   gtk_window_set_default_size( GTK_WINDOW( pwDialog ), 0, 400 );
 
   /* Create notebook pages */
@@ -725,33 +725,19 @@ GTKViewRolloutStatistics(GtkWidget *widget, gpointer data){
 
   gtk_container_set_border_width( GTK_CONTAINER( pwNotebook ), 4 );
 
-  gtk_container_add( GTK_CONTAINER( DialogArea( pwDialog, DA_MAIN ) ),
-                     pwNotebook );
-
-  for ( i = 0; i < nRollouts; i++ ) {
+  gtk_container_add( GTK_CONTAINER( DialogArea( pwDialog, DA_MAIN ) ), pwNotebook );
 
+  for ( i = 0; i < nRollouts; i++ )
+  {
     gtk_clist_get_text ( GTK_CLIST ( prp->pwRolloutResult ),
                               i * 2, 0, &sz );
 
     gtk_notebook_append_page ( GTK_NOTEBOOK ( pwNotebook ),
-                               GTKRolloutStatPage ( &prs[ i * 2 ],
-                                                    cGames ),
-                               gtk_label_new ( sz ) );
-
+		GTKRolloutStatPage ( &prs[ i * 2 ], cGames ), gtk_label_new ( sz ) );
   }
 
-
-  gtk_window_set_modal( GTK_WINDOW( pwDialog ), TRUE );
-  gtk_window_set_transient_for( GTK_WINDOW( pwDialog ),
-                                  GTK_WINDOW( pwMain ) );
-  gtk_signal_connect( GTK_OBJECT( pwDialog ), "destroy",
-                      GTK_SIGNAL_FUNC( gtk_main_quit ), NULL );
-
   gtk_widget_show_all( pwDialog );
-
   gtk_main();
-
-
 }
 
 static void RolloutCancel( GtkObject *po, rolloutprogress *prp ) {
@@ -812,11 +798,8 @@ GTKRolloutProgressStart( const cubeinfo *pci, const int n,
 
   AllocTextList(prp);
 
-  prp->pwRolloutDialog = 
-    GTKCreateDialog( _("GNU Backgammon - Rollout"), DT_INFO,
-                     NULL, NULL );
-  prp->pwRolloutViewStat = 
-    gtk_button_new_with_label ( _("View statistics") );
+  prp->pwRolloutDialog = GTKCreateDialog( _("GNU Backgammon - Rollout"), DT_INFO, NULL, DIALOG_FLAG_MODAL, NULL, NULL );
+  prp->pwRolloutViewStat = gtk_button_new_with_label ( _("View statistics") );
   prp->pwRolloutStop = gtk_button_new_with_label( _("Stop") );
     
   pwOldGrab = pwGrab;
@@ -856,7 +839,7 @@ GTKRolloutProgressStart( const cubeinfo *pci, const int n,
   gtk_clist_column_titles_passive( GTK_CLIST( prp->pwRolloutResult ) );
     
   prp->pwRolloutProgress = gtk_progress_bar_new();
-#if !USE_GTK2
+#if !USE_GTK
   gtk_progress_set_show_text ( GTK_PROGRESS ( prp->pwRolloutProgress ), TRUE );
 #endif
   
@@ -881,7 +864,7 @@ GTKRolloutProgressStart( const cubeinfo *pci, const int n,
                         _("Standard error") );
   }
 
-#if !USE_GTK2
+#if !USE_GTK
   gtk_progress_configure( GTK_PROGRESS( prp->pwRolloutProgress ), 0, 0, 
                           prc->nTrials );
   gtk_progress_set_format_string( GTK_PROGRESS( prp->pwRolloutProgress ),
@@ -920,15 +903,8 @@ GTKRolloutProgressStart( const cubeinfo *pci, const int n,
                       prp->pwSE = gtk_label_new( _("n/a") ),
                       FALSE, FALSE, 4 );
 
-  
-    
   gtk_container_add( GTK_CONTAINER( DialogArea( prp->pwRolloutDialog, DA_MAIN ) ),
                      pwVbox );
-
-  gtk_window_set_modal( GTK_WINDOW( prp->pwRolloutDialog ), TRUE );
-  gtk_window_set_transient_for( GTK_WINDOW( prp->pwRolloutDialog ),
-                                GTK_WINDOW( pwMain ) );
-    
   gtk_widget_show_all( prp->pwRolloutDialog );
 
   /* record start time */
@@ -958,7 +934,7 @@ GTKRolloutProgress( float aarOutput[][ NUM_ROLLOUT_OUTPUTS ],
 
     char sz[ 32 ];
     int i;
-#if USE_GTK2
+#if USE_GTK
     gchar *gsz;
     double frac;
 #endif
@@ -1013,7 +989,7 @@ GTKRolloutProgress( float aarOutput[][ NUM_ROLLOUT_OUTPUTS ],
 	  SetRolloutText(prp, iAlternative * 2, i + 1, "n/a");
 	}
 	  
-#if !USE_GTK2
+#if !USE_GTK
     gtk_progress_configure( GTK_PROGRESS( prp->pwRolloutProgress ),
                             iGame + 1, 0, prc->nTrials );
 #else
@@ -1079,7 +1055,7 @@ GTKRolloutProgress( float aarOutput[][ NUM_ROLLOUT_OUTPUTS ],
 
 static void GTKRolloutProgressEnd( void **pp ) {
     
-#if USE_GTK2
+#if USE_GTK
     gchar *gsz;
 #endif
 
@@ -1102,15 +1078,10 @@ static void GTKRolloutProgressEnd( void **pp ) {
     gtk_widget_set_sensitive( prp->pwRolloutStop, FALSE );
     gtk_widget_set_sensitive( prp->pwRolloutViewStat, TRUE );
 
-#if !USE_GTK2
-    gtk_progress_set_format_string( GTK_PROGRESS( prp->pwRolloutProgress ),
-                                    _("Finished (%v trials)") );
-#else
     gsz = g_strdup_printf( _("Finished (%d trials)") , prp->nGamesDone);
     gtk_progress_bar_set_text( GTK_PROGRESS_BAR( prp->pwRolloutProgress ),
                                     gsz );
     g_free( gsz );
-#endif
 
     gtk_signal_disconnect( GTK_OBJECT( prp->pwRolloutDialog ), 
                            prp->nRolloutSignal );
