@@ -16,33 +16,35 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: relational.c,v 1.18 2005/12/20 19:10:19 Superfly_Jon Exp $
+ * $Id: relational.c,v 1.26 2006/10/09 12:28:43 Superfly_Jon Exp $
  */
 
-#include <stdio.h>
-
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <assert.h>
-#include <glib.h>
-
-#include "i18n.h"
-#include "relational.h"
-#include "backgammon.h"
-#include "positionid.h"
-#include "rollout.h"
-
 #if USE_PYTHON
 
 #include "gnubgmodule.h"
 
 #if USE_GTK
 #include "gtkgame.h"
+#include "gtkwindows.h"
 #endif
 
+#include <stdio.h>
+#include <assert.h>
+#include <glib.h>
+#include <stdlib.h>
+
+#include "relational.h"
+#include "backgammon.h"
+#include "positionid.h"
+#include "rollout.h"
+#include "analysis.h"
+#include <glib/gi18n.h>
+
+
 static void
 LoadDatabasePy( void ) {
 
@@ -122,12 +124,10 @@ static void Disconnect(PyObject *r)
 
 	Py_DECREF(r);
 }
-#endif /* USE_PYTHON */
 
 extern int RelationalMatchExists()
 {
   int ret = -1;
-#if USE_PYTHON
   PyObject *v, *r;
 
   if (!(r = Connect()))
@@ -152,9 +152,6 @@ extern int RelationalMatchExists()
 
   Disconnect(r);
 
-#else /* USE_PYTHON */
-  outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
   return ret;
 }
 
@@ -407,7 +404,6 @@ int MatchAnalysed()
 extern void
 CommandRelationalAddMatch( char *sz ) {
 
-#if USE_PYTHON
   PyObject *v, *r;
   char* env;
   int force = FALSE;
@@ -484,17 +480,12 @@ CommandRelationalAddMatch( char *sz ) {
 
   Disconnect(r);
 
-#else /* USE_PYTHON */
-  outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
-
 }
 
 int env_added;	/* Horrid flag to see if next function worked... */
 
 extern void CommandRelationalAddEnvironment(char *sz)
 {
-#if USE_PYTHON
 	PyObject *v, *r;
 
 	env_added = FALSE;
@@ -538,15 +529,11 @@ extern void CommandRelationalAddEnvironment(char *sz)
 
 	Disconnect(r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 extern void
 CommandRelationalTest( char *sz ) {
 
-#if USE_PYTHON
   PyObject *v, *r;
 
   if (!(r = Connect()))
@@ -583,145 +570,159 @@ CommandRelationalTest( char *sz ) {
 
   Disconnect(r);
 
-#else /* USE_PYTHON */
-  outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
-
 }
 
 extern void
 CommandRelationalHelp( char *sz ) {
-#if USE_PYTHON
 	LoadDatabasePy();
-#endif
   CommandNotImplemented( sz );
 }
 
 extern void
 CommandRelationalShowEnvironments( char *sz )
 {
-#if USE_PYTHON
 	/* Use the Select command */
 	CommandRelationalSelect("place FROM env "
                          "ORDER BY env_id");
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 extern void
-CommandRelationalShowDetails( char *sz )
+CommandRelationalShowDetails (char *sz)
 {
-#if USE_PYTHON
-	PyObject *v, *r;
+  gchar *buf, output[4096], query[2][200], *player_name;
+  RowSet r;
+  gint i, id, query_return;
+  statcontext sc;
 
-	char *player_name, *env;
-
-	if (!sz || !*sz || !(player_name = NextToken(&sz)))
+  if (!sz || !*sz || !(player_name = NextToken (&sz)))
+    {
+      outputl (_("You must specify a player name to list the details for "
+		 "(see `help relational show details')."));
+      return;
+    }
+  buf =
+    g_strdup_printf ("nick.nick_id from nick where nick.name = '%s'",
+		     player_name);
+  if (RunQuery (&r, buf))
+    id = strtol (r.data[1][0], NULL, 0);
+  else {
+	  outputl (_("Player not found or player stats empty"));
+	  return;
+  }
+  g_free (buf);
+  sprintf (query[0], "where matchstat.nick_id = %d", id);
+  sprintf (query[1], "NATURAL JOIN match WHERE "
+		   "(match.nick_id0 = %d OR match.nick_id1 = %d) "
+		   "AND matchstat.nick_id != %d", id, id, id);
+  IniStatcontext (&sc);
+  for (i = 0; i < 2; ++i)
+    {
+      buf = g_strdup_printf ("SUM(total_moves),"
+			     "SUM(unforced_moves),"
+			     "SUM(total_cube_decisions),"
+			     "SUM(close_cube_decisions),"
+			     "SUM(doubles),"
+			     "SUM(takes),"
+			     "SUM(passes),"
+			     "SUM(very_bad_moves),"
+			     "SUM(bad_moves),"
+			     "SUM(doubtful_moves),"
+			     "SUM(unmarked_moves),"
+			     "SUM(good_moves),"
+			     "SUM(very_unlucky_rolls),"
+			     "SUM(unlucky_rolls),"
+			     "SUM(unmarked_rolls),"
+			     "SUM(lucky_rolls),"
+			     "SUM(very_lucky_rolls),"
+			     "SUM(missed_doubles_below_cp),"
+			     "SUM(missed_doubles_above_cp),"
+			     "SUM(wrong_doubles_below_dp),"
+			     "SUM(wrong_doubles_above_tg),"
+			     "SUM(wrong_takes),"
+			     "SUM(wrong_passes),"
+			     "SUM(chequer_error_total_normalised),"
+			     "SUM(error_missed_doubles_below_cp_normalised),"
+			     "SUM(error_missed_doubles_above_cp_normalised),"
+			     "SUM(error_wrong_doubles_below_dp_normalised),"
+			     "SUM(error_wrong_doubles_above_tg_normalised),"
+			     "SUM(error_wrong_takes_normalised),"
+			     "SUM(error_wrong_passes_normalised),"
+			     "SUM(luck_total_normalised)"
+			     "from matchstat " "%s", query[i]);
+      query_return = RunQuery (&r, buf);
+      g_free (buf);
+      if ((!query_return) || !strtol (r.data[1][0], NULL, 0))
 	{
-		outputl( _("You must specify a player name to list the details for "
-		"(see `help relational show details').") );
-		return;
+	  outputl (_("Player not found or player stats empty"));
+	  return;
 	}
-	env = NextToken(&sz);
-	if (!env)
-		env = "";
-
-	r = Connect();
-
-	/* list env */
-	if (!(v = PyObject_CallMethod(r, "list_details", "ss", player_name, env)))
-	{
-		PyErr_Print();
-		return;
-	}
-
-	if (PySequence_Check(v))
-	{
-		int i;
-
-		for ( i = 0; i < PySequence_Size( v ); ++i )
-		{
-			PyObject *e = PySequence_GetItem(v, i);
-
-			if ( !e )
-			{
-				outputf( _("Error getting item no %d\n"), i );
-				continue;
-			}
-
-			if (PySequence_Check(e))
-			{
-				PyObject *detail = PySequence_GetItem(e, 0);
-				PyObject *value = PySequence_GetItem(e, 1);
-
-				if (PyInt_Check(value))
-					outputf( _("%s: %d\n"),
-						PyString_AsString(detail),
-						(int)PyInt_AsLong(value));
-				else if (PyFloat_Check(value))
-					outputf( _("%s: %.2f\n"),
-						PyString_AsString(detail),
-						PyFloat_AsDouble(value));
-				else
-					outputf( _("unknown type"));
-
-				Py_DECREF(detail);
-				Py_DECREF(value);
-			}
-			else
-			{
-				outputf( _("Item no. %d is not a sequence\n"), i );
-				continue;
-			}
-			Py_DECREF( e );
-		}
-		outputl( "" );
-	}
-	else
-	{
-		if (PyInt_Check(v))
-		{
-			int l = PyInt_AsLong(v);
-			if (l == -1)
-				outputl( _("Player not in database") );
-			else if (l == -4)
-				outputl( _("Unknown environment") );
-			else
-				outputl( _("unknown return value") );
-		}
-		else
-			outputl( _("invalid return type") );
-	}
-
-	Py_DECREF( v );
-
-	Disconnect(r);
-
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
+      sc.anTotalMoves[i] = strtol (r.data[1][0], NULL, 0);
+      sc.anUnforcedMoves[i] = strtol (r.data[1][1], NULL, 0);
+      sc.anTotalCube[i] = strtol (r.data[1][2], NULL, 0);
+      sc.anCloseCube[i] = strtol (r.data[1][3], NULL, 0);
+      sc.anDouble[i] = strtol (r.data[1][4], NULL, 0);
+      sc.anTake[i] = strtol (r.data[1][5], NULL, 0);
+      sc.anPass[i] = strtol (r.data[1][6], NULL, 0);
+      sc.anMoves[i][SKILL_VERYBAD] = strtol (r.data[1][7], NULL, 0);
+      sc.anMoves[i][SKILL_BAD] = strtol (r.data[1][8], NULL, 0);
+      sc.anMoves[i][SKILL_DOUBTFUL] = strtol (r.data[1][9], NULL, 0);
+      sc.anMoves[i][SKILL_NONE] = strtol (r.data[1][10], NULL, 0);
+      sc.anMoves[i][SKILL_GOOD] = strtol (r.data[1][11], NULL, 0);
+      sc.anLuck[i][LUCK_VERYBAD] = strtol (r.data[1][12], NULL, 0);
+      sc.anLuck[i][LUCK_BAD] = strtol (r.data[1][13], NULL, 0);
+      sc.anLuck[i][LUCK_NONE] = strtol (r.data[1][14], NULL, 0);
+      sc.anLuck[i][LUCK_GOOD] = strtol (r.data[1][15], NULL, 0);
+      sc.anLuck[i][LUCK_VERYGOOD] = strtol (r.data[1][16], NULL, 0);
+      sc.anCubeMissedDoubleDP[i] = strtol (r.data[1][17], NULL, 0);
+      sc.anCubeMissedDoubleTG[i] = strtol (r.data[1][18], NULL, 0);
+      sc.anCubeWrongDoubleDP[i] = strtol (r.data[1][19], NULL, 0);
+      sc.anCubeWrongDoubleTG[i] = strtol (r.data[1][20], NULL, 0);
+      sc.anCubeWrongTake[i] = strtol (r.data[1][21], NULL, 0);
+      sc.anCubeWrongPass[i] = strtol (r.data[1][22], NULL, 0);
+      sc.arErrorCheckerplay[i][0] = (float)g_strtod (r.data[1][23], NULL);
+      sc.arErrorMissedDoubleDP[i][0] = (float)g_strtod (r.data[1][24], NULL);
+      sc.arErrorMissedDoubleTG[i][0] = (float)g_strtod (r.data[1][25], NULL);
+      sc.arErrorWrongDoubleDP[i][0] = (float)g_strtod (r.data[1][26], NULL);
+      sc.arErrorWrongDoubleTG[i][0] = (float)g_strtod (r.data[1][27], NULL);
+      sc.arErrorWrongTake[i][0] = (float)g_strtod (r.data[1][28], NULL);
+      sc.arErrorWrongPass[i][0] = (float)g_strtod (r.data[1][29], NULL);
+      sc.arLuck[i][0] = (float)g_strtod (r.data[1][30], NULL);
+    }
+  sc.fMoves = 1;
+  sc.fCube = 1;
+  sc.fDice = 1;
+  DumpStatcontext (output, &sc, player_name, _("Opponents"), NULL, FALSE);
+#if USE_GTK
+  if (fX)
+    {
+      GTKTextWindow (output, _("Player statistics"), DT_INFO);
+    }
+  else
+    {
+#endif
+      outputl (_("Player statistics\n\n"));
+      outputl (output);
+#if USE_GTK
+    }
+#endif
 }
 
+
+
 extern void
 CommandRelationalShowPlayers( char *sz )
 {
-#if USE_PYTHON
 	/* Use the Select command */
 	CommandRelationalSelect("person.name AS Player, nick.name AS Nickname, env.place AS env"
 		" FROM nick INNER JOIN env ON nick.env_id = env.env_id"
 		" INNER JOIN person ON nick.person_id = person.person_id"
 		" ORDER BY person.name");
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 extern void CommandRelationalErase(char *sz)
 {
-#if USE_PYTHON
 	PyObject *v, *r;
 	char *player_name, *env;
 
@@ -763,14 +764,10 @@ extern void CommandRelationalErase(char *sz)
 
 	Disconnect(r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 extern void RelationalLinkNick(char* nick, char* env, char* player)
 {	/* Link nick on env to player */
-#if USE_PYTHON
 	PyObject *v, *r;
 
 	r = Connect();
@@ -798,14 +795,10 @@ extern void RelationalLinkNick(char* nick, char* env, char* player)
 
 	Disconnect(r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 extern void CommandRelationalRenameEnv(char *sz)
 {
-#if USE_PYTHON
 	PyObject *v, *r;
 	char *env_name, *new_name;
 
@@ -843,16 +836,12 @@ extern void CommandRelationalRenameEnv(char *sz)
 
 	Disconnect(r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 int env_deleted;	/* Horrid flag to see if next function worked... */
 
 extern void CommandRelationalEraseEnv(char *sz)
 {
-#if USE_PYTHON
 	PyObject *v, *r;
 
 	env_deleted = FALSE;
@@ -898,14 +887,10 @@ extern void CommandRelationalEraseEnv(char *sz)
 
 	Disconnect(r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
 extern void CommandRelationalEraseAll(char *sz)
 {
-#if USE_PYTHON
 	PyObject *v, *r;
 
 	if( fConfirmSave && !GetInputYN( _("Are you sure you want to erase all "
@@ -936,12 +921,8 @@ extern void CommandRelationalEraseAll(char *sz)
 
 	Disconnect(r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
 
-#if USE_PYTHON
 
 extern void FreeRowset(RowSet* pRow)
 {
@@ -980,7 +961,6 @@ void MallocRowset(RowSet* pRow, int rows, int cols)
 	pRow->rows = rows;
 }
 
-#if USE_PYTHON
 extern int UpdateQuery(char *sz)
 {
 	PyObject *v, *r;
@@ -1066,7 +1046,7 @@ extern int RunQuery(RowSet* pRow, char *sz)
 				}
         if (PyUnicode_Check(e2))
         {
-					strcpy(buf, PyString_AsString(PyObject_Str(e2)));
+					strcpy(buf, PyString_AsString(PyUnicode_AsUTF8String(e2)));
 					size = strlen(buf);
         }
 				else if (PyString_Check(e2))
@@ -1081,7 +1061,7 @@ extern int RunQuery(RowSet* pRow, char *sz)
 				}
 				else if (PyFloat_Check(e2))
 				{
-					sprintf(buf, "%.2f", PyFloat_AsDouble(e2));
+					sprintf(buf, "%.4f", PyFloat_AsDouble(e2));
 					size = ((int)log(PyFloat_AsDouble(e2))) + 1 + 3;
 				}
 				else if (e2 == Py_None)
@@ -1117,12 +1097,9 @@ extern int RunQuery(RowSet* pRow, char *sz)
 
 	return TRUE;
 }
-#endif
-#endif
 
 extern void CommandRelationalSelect(char *sz)
 {
-#if USE_PYTHON
 #if !USE_GTK
 	int i, j;
 #endif
@@ -1185,11 +1162,7 @@ extern void CommandRelationalSelect(char *sz)
 #endif
 	FreeRowset(&r);
 
-#else /* USE_PYTHON */
-	outputl( _("This build was not compiled with support for Python.\n") );
-#endif /* !USE_PYTHON */
 }
-#if USE_PYTHON
 extern void RelationalUpdatePlayerDetails(int player_id, const char* newName,
 										  const char* newNotes)
 {
@@ -1219,4 +1192,67 @@ extern void RelationalUpdatePlayerDetails(int player_id, const char* newName,
 	}
 	FreeRowset(&r);
 }
+#else
+#include "backgammon.h"
+#include <glib/gi18n.h>
+extern void
+CommandRelationalAddEnvironment (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalErase (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalRenameEnv (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalEraseEnv (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalEraseAll (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalSelect (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalAddMatch (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalTest (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalHelp (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalShowEnvironments (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalShowDetails (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
+extern void
+CommandRelationalShowPlayers (char *sz)
+{
+  outputl (_("This build was not compiled with support for Python.\n"));
+}
 #endif
