@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: render.c,v 1.35 2004/04/17 21:50:35 oysteijo Exp $
+ * $Id: render.c,v 1.48.2.1 2006/11/10 11:34:40 c_anthon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -30,28 +30,25 @@
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include FT_GLYPH_H
+#include "path.h"
 #endif
 #include <isaac.h>
 #include <math.h>
 #include <stdlib.h>
 
-#if HAVE_LIBART
-#include <libart_lgpl/art_misc.h>
-#include <libart_lgpl/art_affine.h>
-#include <libart_lgpl/art_point.h>
-#include <libart_lgpl/art_vpath.h>
-#include <libart_lgpl/art_bpath.h>
-#include <libart_lgpl/art_vpath_bpath.h>
-#include <libart_lgpl/art_svp.h>
-#include <libart_lgpl/art_svp_vpath.h>
-#include <libart_lgpl/art_gray_svp.h>
-#include <libart_lgpl/art_rgb.h>
-#include <libart_lgpl/art_rgb_svp.h>
+#if HAVE_ALLOCA_H
+#include <alloca.h>
 #endif
 
 #include "render.h"
 #include "renderprefs.h"
 #include "boarddim.h"
+#include "backgammon.h"
+
+#if USE_GTK
+#include <gtk/gtk.h>
+#include <cairo.h>
+#endif
 
 static randctx rc;
 #define RAND irand( &rc )
@@ -128,21 +125,17 @@ FT_Library ftl;
 #define FT_GLYPH_FORMAT_BITMAP ft_glyph_format_bitmap
 #define FT_PIXEL_MODE_GRAY ft_pixel_mode_grays
 #endif
-
-extern unsigned char auchLuxiRB[], auchLuxiSB[], auchLuxiSR[];
-extern unsigned int cbLuxiRB, cbLuxiSB, cbLuxiSR;
-
 #endif
 
 renderdata rdDefault = {
     WOOD_ALDER, /* wt */
-    { { 1.0, 0.2, 0.2, 0.9 }, { 0.05, 0.05, 0.1, 0.5 } }, /* aarColour */
-    { { 1.0, 0.2, 0.2, 0.9 }, { 0.05, 0.05, 0.1, 0.5 } }, /* aarDiceColour */
+    { { 0xF1 / 255.0, 0x25 / 255.0, 0x25 / 255.0, 0.9 }, { 0, 0, 0xB / 255.0, 0.5 } }, /* aarColour */
+    { { 0xF1 / 255.0, 0x25 / 255.0, 0x25 / 255.0, 0.9 }, { 0, 0, 0xB / 255.0, 0.5 } }, /* aarDiceColour */
     { TRUE, TRUE }, /* afDieColour */
-    { { 0.7, 0.7, 0.7, 1.0 }, { 0.7, 0.7, 0.7, 1.0 } }, /* aarDiceDotColour */
-    { 0.9, 0.9, 0.9, 1.0 }, /* arCubeColour */
-    { { 0x30, 0x60, 0x30, 0xFF }, { 0x00, 0x40, 0x00, 0xFF },
-      { 0xFF, 0x60, 0x60, 0xFF }, { 0xC0, 0xC0, 0xC0, 0xFF } }, /* aanBoardC */
+    { { 0xA4 / 255.0, 0xA4 / 255.0, 0xA4 / 255.0, 1.0 }, { 0xA4 / 255.0, 0xA4 / 255.0, 0xA4 / 255.0, 1.0 } }, /* aarDiceDotColour */
+    { 0xD7 / 255.0, 0xD7 / 255.0, 0xD7 / 255.0, 1.0 }, /* arCubeColour */
+    { { 0x2F, 0x5F, 0x2F, 0xFF }, { 0x00, 0x3F, 0x00, 0xFF },
+      { 0xFF, 0x5F, 0x5F, 0xFF }, { 0xBF, 0xBF, 0xBF, 0xFF } }, /* aanBoardC */
     { 25, 25, 25, 25 }, /* aSpeckle */
     { 1.5, 1.5 }, /* arRefraction */
     { 0.2, 1.0 }, /* arCoefficient */
@@ -174,15 +167,17 @@ renderdata rdDefault = {
 	LT_POSITIONAL, /* light source type */
 	{0, 2, 3.5f},	/* x,y,z pos of light source */
 	{50, 70, 100},	/* amibient/diffuse/specular light levels */
-	35,	/* Board angle */
+	15,	/* Board angle */
 	20,	/* FOV skew factor */
 	0,	/* Plan view */
-	3,	/* Dice size */
+	2.5f,	/* Dice size */
 	0,	/* Rounded edges */
 	1,	/* Background in trays */
+	0,	/* Rounded points */
 	PT_ROUNDED,	/* Piece type */
 	PTT_ALL,	/* Piece texture type */
     { TRUE, TRUE }, /* afDieColour3d */
+	0, 0,	/* Used at runtime */
 	/* Default 3d colours - black+white, should never be used -
 		if no 3d settings the first design will be used */
     {{{1, 1, 1, 1}, {1, 1, 1, 1}, {1, 1, 1, 1}, 100, 0, 0},
@@ -664,11 +659,7 @@ static void RenderFramePainted( renderdata *prd, unsigned char *puch,
 				int nStride ) {
     int i, ix;
     float x, z, cos_theta, diffuse, specular;
-#if __GNUC__ || !HAVE_ALLOCA
-	unsigned char colours[ 4 * 3 * prd->nSize ];
-#else
-	unsigned char *colours = (unsigned char*)alloca( 4 * 3 * prd->nSize * sizeof(unsigned char) );
-#endif
+	VARIABLE_ARRAY(unsigned char, colours, 4 * 3 * prd->nSize)
 
     diffuse = 0.8 * prd->arLight[ 2 ] + 0.2;
     specular = pow( prd->arLight[ 2 ], 20 ) * 0.6;
@@ -1523,13 +1514,17 @@ RenderLabels( renderdata *prd, unsigned char *puch, int nStride,
     FT_Face ftf;
     int i;
     FT_Glyph aftg[ 10 ];
+    char *file;
 
-    if( FT_New_Memory_Face( ftl, auchLuxiSB, cbLuxiSB, 0, &ftf ) )
+    file = PathSearch(FONT_VERA, szDataDirectory);
+    if( FT_New_Face( ftl, file, 0, &ftf ) )
 	{
 		RenderBasicLabels( prd, puch, nStride, iStart, iEnd, iDelta );
+                free(file);
 		return;
 	}
-    
+    free(file);
+
     if( FT_Set_Pixel_Sizes( ftf, 0, prd->nSize * 5 / 2 ) )
 	{
 		RenderBasicLabels( prd, puch, nStride, iStart, iEnd, iDelta );
@@ -1785,8 +1780,10 @@ extern void RenderChequers( renderdata *prd, unsigned char *puch0,
 			1 / ( 1 - prd->rRound ) + 1;
 		s = ssqrt( 1 - r * r );
 		s1 = ssqrt( 1 - r1 * r1 );
-		
-		theta = atanf( r1 / s1 );
+		if (s1 != 0)
+			theta = atanf( r1 / s1 );
+		else
+			theta = 0;
 		
 		for( f = 0; f < 2; f++ ) {
 		    b = asinf( sinf( theta ) / prd->arRefraction[ f ] );
@@ -1854,8 +1851,10 @@ extern void RenderChequerLabels( renderdata *prd, unsigned char *puch,
     FT_Face ftf;
     FT_Glyph aftg[ 10 ];
     int fFreetype = FALSE;
+    char *file;
     
-    if( !FT_New_Memory_Face( ftl, auchLuxiSR, cbLuxiSR, 0, &ftf ) &&
+    file = PathSearch(FONT_VERA, szDataDirectory);
+    if( !FT_New_Face( ftl, file, 0, &ftf ) &&
 	!FT_Set_Pixel_Sizes( ftf, 0, 2 * prd->nSize ) ) {
 	fFreetype = TRUE;
 	for( i = 0; i < 10; i++ ) {
@@ -1865,6 +1864,7 @@ extern void RenderChequerLabels( renderdata *prd, unsigned char *puch,
 
 	FT_Done_Face( ftf );
     }
+    free(file);
 #endif
 
     for( i = 0; i < 12; i++ ) {
@@ -2031,9 +2031,11 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
     FT_Face ftf;
     FT_Glyph aftg[ 10 ], aftgSmall[ 10 ];
     int fFreetype = FALSE;
+    char *file;
     
-    if( !FT_New_Memory_Face( ftl, auchLuxiRB, cbLuxiRB, 0, &ftf ) &&
-	!FT_Set_Pixel_Sizes( ftf, 0, 5 * prd->nSize ) ) {
+    file = PathSearch(FONT_VERA_SERIF_BOLD, szDataDirectory);
+    if( !FT_New_Face( ftl, file, 0, &ftf ) &&
+	!FT_Set_Pixel_Sizes( ftf, 0, 4.5 * prd->nSize ) ) {
 	fFreetype = TRUE;
 	
 	for( i = 0; i < 10; i++ ) {
@@ -2041,7 +2043,7 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
 	    FT_Get_Glyph( ftf->glyph, aftg + i );
 	}
 	
-	FT_Set_Pixel_Sizes( ftf, 0, 21 * prd->nSize / 8 );
+	FT_Set_Pixel_Sizes( ftf, 0, 2 * prd->nSize );
 	
 	for( i = 0; i < 10; i++ ) {
 	    FT_Load_Char( ftf, '0' + i, FT_LOAD_RENDER );
@@ -2050,9 +2052,13 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
 	
 	FT_Done_Face( ftf );
     }
+    free(file);
 #endif
     
     for( i = 0; i < 6; i++ ) {
+	/* Clear destination buffer (no blending at present - so all overwriten anyway) */
+	memset(puch, 0, nStride * CUBE_LABEL_HEIGHT * prd->nSize);
+
 	AlphaBlendBase( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
 		    prd->nSize * nStrideCube, nStrideCube,
 		    CUBE_LABEL_WIDTH * prd->nSize, CUBE_LABEL_HEIGHT * prd->nSize );
@@ -2060,7 +2066,7 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
 #if HAVE_FREETYPE
 	if( fFreetype )
 	    RenderNumber( puch, nStride, aftg, 2 << i, 3 * prd->nSize,
-			  78 * prd->nSize / 16, 0, 0, 0x80 );
+			  4.8 * prd->nSize, 0, 0, 0x80 );
 	else
 #endif
 	    RenderBasicNumber( puch, nStride, 4 * prd->nSize, 2 << i,
@@ -2070,6 +2076,9 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
     }
     
     for( ; i < 12; i++ ) {
+	/* Clear destination buffer (no blending at present - so all overwriten anyway) */
+	memset(puch, 0, nStride * CUBE_LABEL_HEIGHT * prd->nSize);
+
 	AlphaBlendBase( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
  		    prd->nSize * nStrideCube, nStrideCube,
 		    CUBE_LABEL_WIDTH * prd->nSize, CUBE_LABEL_HEIGHT * prd->nSize );
@@ -2105,8 +2114,10 @@ extern void RenderResignFaces( renderdata *prd, unsigned char *puch,
     FT_Face ftf;
     FT_Glyph aftg[ 10 ], aftgSmall[ 10 ];
     int fFreetype = FALSE;
+    char *file;
     
-    if( !FT_New_Memory_Face( ftl, auchLuxiRB, cbLuxiRB, 0, &ftf ) &&
+    file = PathSearch(FONT_VERA_SERIF_BOLD, szDataDirectory);
+    if( !FT_New_Face( ftl, file, 0, &ftf ) &&
 	!FT_Set_Pixel_Sizes( ftf, 0, 5 * prd->nSize ) ) {
 	fFreetype = TRUE;
 	
@@ -2124,9 +2135,13 @@ extern void RenderResignFaces( renderdata *prd, unsigned char *puch,
 	
 	FT_Done_Face( ftf );
     }
+    free(file);
 #endif
     
     for( i = 0; i < 3; i++ ) {
+	/* Clear destination buffer (no blending at present - so all overwriten anyway) */
+	memset(puch, 0, nStride * RESIGN_LABEL_HEIGHT * prd->nSize);
+
 	AlphaBlendBase( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
 		    prd->nSize * nStrideCube, nStrideCube,
 		    RESIGN_LABEL_WIDTH * prd->nSize, RESIGN_LABEL_HEIGHT * prd->nSize );
@@ -2147,8 +2162,10 @@ extern void RenderResignFaces( renderdata *prd, unsigned char *puch,
     
 #if HAVE_FREETYPE
     if( fFreetype )
-	for( i = 0; i < 10; i++ ) 
+	for( i = 0; i < 10; i++ ) {
 	    FT_Done_Glyph( aftg[ i ] );
+	    FT_Done_Glyph( aftgSmall[ i ] );
+	}
 #endif
 }
 
@@ -2200,8 +2217,8 @@ extern void RenderDice( renderdata *prd, unsigned char *puch0,
 			    arDiceCoefficient[ 1 ];
 		    } else {
 			/* corner */
-			x_norm = 0.707 * x; // - ( x > 0.0 ? 1.0 : 1.0); 
-			y_norm = -0.707 * y; // - ( y > 0.0 ? 1.0 : 1.0 );
+		      x_norm = 0.707 * x; /* - ( x > 0.0 ? 1.0 : 1.0);  */
+		      y_norm = -0.707 * y; /* - ( y > 0.0 ? 1.0 : 1.0 ); */
 			z_norm = 1 - x_norm * x_norm - y_norm * y_norm; 
 			z_norm = ssqrt( z_norm );
 			
@@ -2365,183 +2382,59 @@ static void Copy_RGB_to_RGBA( unsigned char *puchDest, int nDestStride,
     }
 }
 
-#if HAVE_LIBART
-static void InsertAlpha( unsigned char *puchDest, int nDestStride,
-		         unsigned char *puchAlpha, int nAlphaStride,
-		         int cx, int cy ) {
-/* insert an alpha channel mask into an 24+8-bit RGBA buffer of
-   dimension cx x cy */
+#if USE_GTK
+static void RenderArrow(unsigned char* puch, double arColour[4], int nSize, int up)
+{
+	cairo_surface_t* surface = cairo_image_surface_create_for_data (puch, CAIRO_FORMAT_RGB24,
+												nSize * ARROW_WIDTH,
+												nSize * ARROW_HEIGHT,
+												nSize * ARROW_WIDTH * 4);
+	cairo_t* cr = cairo_create(surface);
 
-    int x;
+#define AR_LINE_WIDTH 0.01
+#define AR_WIDTH 0.4
+#define AR_HEAD_SIZE 0.4
 
-    nDestStride -= cx * 4;  /* 8 bit alpha + 24 packed rgb bits */
-    nAlphaStride -= cx * 1; /* 8 bit alpha */
+	cairo_scale(cr, nSize * ARROW_WIDTH, nSize * ARROW_HEIGHT);
 
-    for( ; cy; cy-- ) {
-	for( x = cx; x; x-- ) {
-	    puchDest += 3;  /* advance to alpha */
-	    *puchDest++ = *puchAlpha++;
+	if (!up)
+	{	/* Rotate by 180 degrees */
+		cairo_translate(cr, .5, .5);
+		cairo_rotate(cr, PI);
+		cairo_translate(cr, -.5, -.5);
 	}
-	puchDest += nDestStride;
-	puchAlpha += nAlphaStride;
-    }
+
+	cairo_set_line_width (cr, AR_LINE_WIDTH);
+
+	cairo_set_source_rgba (cr, 0, 0, 0, 1);
+	cairo_rectangle(cr, 0, 0, 1, 1);
+	cairo_fill(cr);
+
+	cairo_move_to (cr, (1 - AR_WIDTH) / 2, 1 - AR_LINE_WIDTH);
+	cairo_line_to (cr, 1 - (1 - AR_WIDTH) / 2, 1 - AR_LINE_WIDTH);
+	cairo_line_to (cr, 1 - (1 - AR_WIDTH) / 2, AR_HEAD_SIZE);
+	cairo_line_to (cr, 1 - AR_LINE_WIDTH, AR_HEAD_SIZE);
+	cairo_line_to (cr, 0.5, AR_LINE_WIDTH);
+	cairo_line_to (cr, AR_LINE_WIDTH, AR_HEAD_SIZE);
+	cairo_line_to (cr, (1 - AR_WIDTH) / 2, AR_HEAD_SIZE);
+	cairo_close_path(cr);
+
+	cairo_set_source_rgba (cr, arColour[2], arColour[1], arColour[0], 1);
+	cairo_fill_preserve (cr);
+	cairo_set_source_rgba (cr, 0, 0, 0, 1);
+	cairo_stroke(cr);
+
+	cairo_destroy (cr);
+	cairo_surface_destroy(surface);
 }
 
-static ArtBpath * Make_Path_Arrow( void ) {
-/* set up a B-spline vector path representing an arrow */
-
-    ArtBpath *vec = NULL;
-
-    vec = art_new( ArtBpath, 10 );
-    vec[0].code = ART_MOVETO;
-    vec[0].y1 = 0.;
-    vec[0].y1 = 0.;
-    vec[0].y2 = 0.;
-    vec[0].y2 = 0.;
-    vec[0].x3 = 5.;
-    vec[0].y3 = 0.;
-    vec[1].code = ART_LINETO;
-    vec[1].y1 = 0.;
-    vec[1].y1 = 0.;
-    vec[1].y2 = 0.;
-    vec[1].y2 = 0.;
-    vec[1].x3 = 0.;
-    vec[1].y3 = 4.;
-    vec[2].code = ART_LINETO;
-    vec[2].y1 = 0.;
-    vec[2].y1 = 0.;
-    vec[2].y2 = 0.;
-    vec[2].y2 = 0.;
-    vec[2].x3 = 3.;
-    vec[2].y3 = 4.;
-    vec[3].code = ART_LINETO;
-    vec[3].y1 = 0.;
-    vec[3].y1 = 0.;
-    vec[3].y2 = 0.;
-    vec[3].y2 = 0.;
-    vec[3].x3 = 3.;
-    vec[3].y3 = 10.;
-    vec[4].code = ART_LINETO;
-    vec[4].y1 = 0.;
-    vec[4].y1 = 0.;
-    vec[4].y2 = 0.;
-    vec[4].y2 = 0.;
-    vec[4].x3 = 7.;
-    vec[4].y3 = 10.;
-    vec[5].code = ART_LINETO;
-    vec[5].y1 = 0.;
-    vec[5].y1 = 0.;
-    vec[5].y2 = 0.;
-    vec[5].y2 = 0.;
-    vec[5].x3 = 7.;
-    vec[5].y3 = 4.;
-    vec[6].code = ART_LINETO;
-    vec[6].y1 = 0.;
-    vec[6].y1 = 0.;
-    vec[6].y2 = 0.;
-    vec[6].y2 = 0.;
-    vec[6].x3 = 10.;
-    vec[6].y3 = 4.;
-    vec[7].code = ART_LINETO;
-    vec[7].y1 = 0.;
-    vec[7].y1 = 0.;
-    vec[7].y2 = 0.;
-    vec[7].y2 = 0.;
-    vec[7].x3 = 5.;
-    vec[7].y3 = 0.;
-    vec[8].code = ART_END;
-
-    return vec;
-}
-#endif /* HAVE_LIBART */
-
-#if HAVE_LIBART
-static void Render_Path( art_u8 *puchRGBAbuf, const ArtBpath* bpPath,
-			 int iWidth, int iHeight,
-			 art_u32 fg_color, art_u32 bg_color ) {
-/* render an anti-aliased vector path filled with fg_color into an RGBA buffer
-   of dimension iWidth x iHeight, make background transparent (alpha mask) */
-
-    art_u8 *puchRGBbuf = NULL;
-    art_u8 *puchAlphabuf = NULL;
-    double adAffine[6];
-    ArtBpath *bpTransformed = NULL;
-    ArtVpath *vpTransformed = NULL;
-    ArtSVP *svp = NULL;
-
-    art_affine_scale( adAffine, iWidth/10.0, iHeight/10.0 ); /* assume a vector area of [0,10] */
-    bpTransformed = art_bpath_affine_transform( bpPath, adAffine );
-
-    vpTransformed = art_bez_path_to_vec( bpTransformed, 0. );
-    svp = art_svp_from_vpath( vpTransformed );
-    art_free( vpTransformed );
-
-    puchRGBbuf = art_new( art_u8, iWidth*iHeight*3 );	/* 24 packed rgb bits */
-    assert( puchRGBbuf );
-    /* fill with background colour */
-    art_rgb_fill_run( puchRGBbuf, 0x00, 0x00, 0x00, iWidth*iHeight );
-    /* render foreground */
-    art_rgb_svp_aa( svp, 0, 0, iWidth, iHeight, fg_color, bg_color,
-		    puchRGBbuf, iWidth*3, NULL );
-    /* convert */
-    assert( puchRGBAbuf );
-    Copy_RGB_to_RGBA( puchRGBAbuf, iWidth*4, puchRGBbuf, iWidth*3,
-		      iWidth, iHeight, 0xFF );
-    art_free( puchRGBbuf );
-    /* render alpha */
-    puchAlphabuf = art_new( art_u8, iWidth*iHeight*1 );	/* 8 bit alpha */
-    assert( puchAlphabuf );
-    art_gray_svp_aa( svp, 0, 0, iWidth, iHeight, puchAlphabuf, iWidth*1 );
-    /* integrate alpha information from puchAlphabuf into puchRGBAbuf */
-    InsertAlpha( puchRGBAbuf, iWidth*4,
-		 puchAlphabuf, iWidth*1, iWidth, iHeight );
-    art_free( puchAlphabuf );
-    art_free( svp );
-}
-#endif /* HAVE_LIBART */
-
-#if HAVE_LIBART
 extern void RenderArrows( renderdata *prd, unsigned char* puch0,
-			  unsigned char* puch1, int nStride ) {
-/* render arrows for direction of play and player on turn */
-
-    ArtBpath *bpArrow = NULL;
-    ArtBpath *bpTmp = NULL;
-    double adAffine[6];
-    art_u32 fg_colour = (0xFF << 24) |
-			( (art_u8) ( prd->aarColour[ 0 ][ 0 ] * 0xFF ) << 16 ) |
-			( (art_u8) ( prd->aarColour[ 0 ][ 1 ] * 0xFF ) <<  8 ) |
-			( (art_u8) ( prd->aarColour[ 0 ][ 2 ] * 0xFF ) );	/* AARRGGBB */
-    art_u32 bg_colour = 0xFFC9CACB;
-
-    bpArrow = Make_Path_Arrow();
-
-    /* player 0 */
-    Render_Path( (art_u8 *) puch0, bpArrow, prd->nSize * ARROW_WIDTH,
-		 prd->nSize * ARROW_HEIGHT, fg_colour, bg_colour );
-
-    /* set up a 180 rotation around (5,5) */
-    adAffine[0] = -1.;
-    adAffine[1] = 0.;
-    adAffine[2] = 0.;
-    adAffine[3] = -1.;
-    adAffine[4] = 10.;
-    adAffine[5] = 10.;
-    bpTmp = art_bpath_affine_transform( bpArrow, adAffine );
-    art_free( bpArrow );
-
-    fg_colour = (0xFF << 24) |
-		( (art_u8) ( prd->aarColour[ 1 ][ 0 ] * 0xFF ) << 16 ) |
-		( (art_u8) ( prd->aarColour[ 1 ][ 1 ] * 0xFF ) <<  8 ) |
-		( (art_u8) ( prd->aarColour[ 1 ][ 2 ] * 0xFF ) );	/* AARRGGBB */
-
-    /* player 1 */
-    Render_Path( (art_u8 *) puch1, bpTmp, prd->nSize * ARROW_WIDTH,
-		 prd->nSize * ARROW_HEIGHT, fg_colour, bg_colour );
-
-    art_free( bpTmp );
+			  unsigned char* puch1, int nStride )
+{
+	RenderArrow(puch0, prd->aarColour[0], prd->nSize, TRUE);
+	RenderArrow(puch1, prd->aarColour[1], prd->nSize, FALSE);
 }
-#endif /* HAVE_LIBART */
+#endif
 
 static void PointArea( renderdata *prd, int n, int *px, int *py,
 		       int *pcx, int *pcy ) {
@@ -2813,8 +2706,7 @@ extern void CalculateArea( renderdata *prd, unsigned char *puch, int nStride,
     }
 
     /* draw arrow for direction of play */
-
-#if HAVE_LIBART
+#if USE_GTK
     if( prd->showMoveIndicator &&
 			intersects( x, y, cx, cy,
                     anArrowPosition[ 0 ], anArrowPosition[ 1 ],
@@ -2831,9 +2723,8 @@ extern void CalculateArea( renderdata *prd, unsigned char *puch, int nStride,
 			 prd->nSize * ARROW_WIDTH * 4,
 			 0, 0,
 			 prd->nSize * ARROW_WIDTH, prd->nSize * ARROW_HEIGHT );
-    }
-#endif /* HAVE_LIBART */
-
+		}
+#endif
 }
 
 extern void
@@ -2890,13 +2781,13 @@ extern void RenderImages( renderdata *prd, renderimages *pri ) {
     pri->achResign = malloc ( nSize * nSize * RESIGN_WIDTH * RESIGN_HEIGHT * 4 );
     pri->achResignFaces = malloc ( nSize * nSize * RESIGN_LABEL_WIDTH * 
 				   RESIGN_LABEL_HEIGHT * 3 * 3 );
-#if HAVE_LIBART
-    pri->auchArrow[0] = art_new( art_u8, nSize * nSize * ARROW_WIDTH * ARROW_HEIGHT * 4 );
-    pri->auchArrow[1] = art_new( art_u8, nSize * nSize * ARROW_WIDTH * ARROW_HEIGHT * 4 );
+#if USE_GTK
+    pri->auchArrow[0] = malloc(prd->nSize * prd->nSize * ARROW_WIDTH * ARROW_HEIGHT * 4 );
+    pri->auchArrow[1] = malloc(prd->nSize * prd->nSize * ARROW_WIDTH * ARROW_HEIGHT * 4 );
 #else
     pri->auchArrow[0] = NULL;
     pri->auchArrow[1] = NULL;
-#endif /* HAVE_LIBART */
+#endif
     for ( i = 0; i < 2; ++i )
       pri->achLabels[ i ] = malloc( nSize * nSize * BOARD_WIDTH * 
 				    BORDER_HEIGHT * 4 );
@@ -2915,10 +2806,10 @@ extern void RenderImages( renderdata *prd, renderimages *pri ) {
     RenderResign( prd, pri->achResign, nSize * RESIGN_WIDTH * 4 );
     RenderResignFaces( prd, pri->achResignFaces, nSize * RESIGN_LABEL_WIDTH * 3,
 		       pri->achResign, nSize * RESIGN_WIDTH * 4 );
-#if HAVE_LIBART
+#if USE_GTK
 	if (prd->showMoveIndicator)
 		RenderArrows( prd, pri->auchArrow[0], pri->auchArrow[1], nSize * ARROW_WIDTH * 4 );
-#endif /* HAVE_LIBART */
+#endif
 
     RenderBoardLabels( prd, pri->achLabels[ 0 ], pri->achLabels[ 1 ],
                        BOARD_WIDTH * nSize * 4 );
@@ -2943,10 +2834,10 @@ extern void FreeImages( renderimages *pri ) {
     free( pri->asRefract[ 1 ] );
     free( pri->achResign );
     free( pri->achResignFaces );
-#if HAVE_LIBART
-    art_free( pri->auchArrow[0] );
-    art_free( pri->auchArrow[1] );
-#endif /* HAVE_LIBART */
+#if USE_GTK
+    free( pri->auchArrow[0] );
+    free( pri->auchArrow[1] );
+#endif
     for ( i = 0; i < 2; ++i )
       free( pri->achLabels[ i ] );
 }
@@ -2962,6 +2853,13 @@ extern void RenderInitialise( void ) {
 #endif
 }
 
+extern void RenderFinalise( void )
+{
+#if HAVE_FREETYPE
+    FT_Done_FreeType( ftl );
+#endif
+}
+
 int TolComp(double f1, double f2)
 {
 	return fabs(f1 - f2) < .005;
@@ -3014,6 +2912,7 @@ extern int PreferenceCompare(renderdata *prd1, renderdata *prd2)
 			prd1->pieceTextureType == prd2->pieceTextureType &&
 			prd1->roundedEdges == prd2->roundedEdges &&
 			prd1->bgInTrays == prd2->bgInTrays &&
+			prd1->roundedPoints == prd2->roundedPoints &&
 			prd1->lightType == prd2->lightType &&
 			(prd1->lightPos[0] == prd2->lightPos[0] &&
 			prd1->lightPos[1] == prd2->lightPos[1] &&
@@ -3024,8 +2923,10 @@ extern int PreferenceCompare(renderdata *prd1, renderdata *prd2)
 			!memcmp(prd1->afDieColour3d, prd2->afDieColour3d, sizeof(prd1->afDieColour3d)) &&
 			MaterialTextCompare(&prd1->ChequerMat[0], &prd2->ChequerMat[0]) &&
 			MaterialCompare(&prd1->ChequerMat[1], &prd2->ChequerMat[1]) &&
-			MaterialCompare(&prd1->DiceMat[0], &prd2->DiceMat[0]) &&
-			MaterialCompare(&prd1->DiceMat[1], &prd2->DiceMat[1]) &&
+			(prd1->afDieColour3d[0] ||
+				MaterialCompare(&prd1->DiceMat[0], &prd2->DiceMat[0])) &&
+			(prd1->afDieColour3d[1] ||
+				MaterialCompare(&prd1->DiceMat[1], &prd2->DiceMat[1])) &&
 			MaterialCompare(&prd1->DiceDotMat[0], &prd2->DiceDotMat[0]) &&
 			MaterialCompare(&prd1->DiceDotMat[1], &prd2->DiceDotMat[1]) &&
 			MaterialCompare(&prd1->CubeMat, &prd2->CubeMat) &&
@@ -3058,9 +2959,9 @@ extern int PreferenceCompare(renderdata *prd1, renderdata *prd2)
 			ColourCompare(prd1->aarDiceDotColour[0], prd2->aarDiceDotColour[0]) &&
 			ColourCompare(prd1->aarDiceDotColour[1], prd2->aarDiceDotColour[1]) &&
 			ColourCompare(prd1->arCubeColour, prd2->arCubeColour) &&
-			(prd1->arLight[0] == prd2->arLight[0] &&
-			prd1->arLight[1] == prd2->arLight[1] &&
-			prd1->arLight[2] == prd2->arLight[2]) &&
+			(TolComp(prd1->arLight[0], prd2->arLight[0]) &&
+			TolComp(prd1->arLight[1], prd2->arLight[1]) &&
+			TolComp(prd1->arLight[2], prd2->arLight[2])) &&
 			!memcmp(prd1->aanBoardColour[0], prd2->aanBoardColour[0], sizeof(prd1->aanBoardColour[0])) &&
 			!memcmp(prd1->aanBoardColour[1], prd2->aanBoardColour[1], sizeof(prd1->aanBoardColour[1])) &&
 			!memcmp(prd1->aanBoardColour[2], prd2->aanBoardColour[2], sizeof(prd1->aanBoardColour[2])) &&
