@@ -23,7 +23,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: gnubg.py,v 1.1 2004/02/19 09:41:26 uid68519 Exp $
+# $Id: gnubg.py,v 1.2 2006/04/16 10:50:49 c_anthon Exp $
 #
 
 
@@ -83,7 +83,7 @@ def exportBad(baseName) :
           if skillBad(analysis.get("cube-skill", None)) :
             bad = True
         elif type == "take" or type == "drop" :
-          if badSkill(prevSkill) :
+          if skillBad(prevSkill) :
             # Already exported
             bad = False
 
