@@ -20,7 +20,7 @@
  * File modified by Joern Thyssen <jthyssen@dk.ibm.com> for use with
  * GNU Backgammon.
  *
- * $Id: sound.c,v 1.35 2004/04/16 16:00:37 Superfly_Jon Exp $
+ * $Id: sound.c,v 1.43 2006/06/22 22:50:29 Superfly_Jon Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -80,9 +80,11 @@
 #include <mmsystem.h>
 #endif
 
+#include <glib.h>
+
 #include "backgammon.h"
 #include "eval.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "sound.h"
 #include "path.h"
 
@@ -90,6 +92,8 @@
 #define SIGIO SIGPOLL /* The System V equivalent */
 #endif
 
+#if USE_SOUND
+
 #define MAX_SOUND_LENGTH 1048576
 
 char *aszSoundDesc[ NUM_SOUNDS ] = {
@@ -577,7 +581,7 @@ static void play_audio_file(soundcache *psc, const char *file,
     }
 #elif defined( AUDIO_SETINFO )
     {
-	struct audio_info_t ait;
+	audio_info_t ait;
 
 	AUDIO_INITINFO( &ait );
 	ait.play.sample_rate = psc->nSampleRate;
@@ -605,12 +609,17 @@ static void play_audio_file(soundcache *psc, const char *file,
     pSound_ = pSoundCurrent = psc->pch;
     cbSound = psc->cb;
     hSound = fd;
-    
-#if O_ASYNC
+
+#if defined(O_ASYNC) || defined(__CYGWIN__)
     /* BSD O_ASYNC-style I/O notification */
     if( ( n = fcntl( fd, F_GETFL ) ) != -1 ) {
 	fcntl( fd, F_SETOWN, getpid() );
+#if !defined(__CYGWIN__)
 	fcntl( fd, F_SETFL, n | O_ASYNC | O_NONBLOCK );
+#else
+	fcntl( fd, F_SETFL, n | FASYNC | O_NONBLOCK );
+#endif
+
     }
 #else
     /* System V SIGPOLL-style I/O notification */
@@ -663,10 +672,11 @@ static char *can_play_audio( void ) {
 
 #if HAVE_ARTSC
 
-static int _af_ulaw2linear(unsigned char ulawbyte);
-
 #ifndef HAVE_AF_ULAW2LINEAR
 
+static int _af_ulaw2linear(unsigned char ulawbyte); 
+
+
 /*
 ** This routine converts from ulaw to 16 bit linear.
 **
@@ -700,6 +710,9 @@ static int _af_ulaw2linear(unsigned char ulawbyte)
 	return (sample);
 }
 
+#else
+int _af_ulaw2linear(unsigned char ulawbyte); 
+
 #endif /* !HAVE_AF_ULAW2LINEAR */
 
 
@@ -1042,12 +1055,7 @@ play_file_child(soundcache *psc, const char *filename) {
         char *args[4];
         char command[4096];
 
-#if USE_GTK
         g_snprintf(command, sizeof(command), szSoundCommand, filename);
-#else
-	sprintf( command, szSoundCommand, filename );
-#endif
-	
         args[0] = "sh";
         args[1] = "-c";
         args[2] = command;
@@ -1297,3 +1305,4 @@ extern void SoundWait( void ) {
 	return;
     }
 }
+#endif
