@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: timecontrol.c,v 1.18 2004/05/07 14:28:23 thyssen Exp $
+ * $Id: timecontrol.c,v 1.23.2.1 2006/11/06 23:29:34 c_anthon Exp $
  */
 
 #include "config.h"
@@ -34,7 +34,7 @@
 #include "backgammon.h"
 #include "eval.h"
 
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "sound.h"
 #include "timecontrol.h"
 
@@ -51,7 +51,7 @@
 #if USE_TIMECONTROL
 
 timecontrol tc=
-	{ 0, 0, 0, 0, 0, 0,  0, 1.0, 0, 0, 0};
+	{ 0, 0, 0, 0, 0, 0,  0, 1, 0, 0, 0};
 
 /* Key values */
 static char szTCPLAIN[] = N_("plain")
@@ -369,7 +369,7 @@ static void showTimeControl( timecontrol *ptc, int level, int levels )
       break;
     }
     outputf("%*s%-*s (%s): ", 2*level,"",
-		30-strlen(szTCPENALTY),
+		(int)(30-strlen(szTCPENALTY)),
 		"Penalty points",
 		szTCPENALTY);
     if (TC_LOSS == ptc->penalty)
@@ -379,13 +379,13 @@ static void showTimeControl( timecontrol *ptc, int level, int levels )
 
     /* if (ptc->nAddedTime) */
 	outputf("%*s%-*s (%s): %9s\n", 2*level,"",
-		30-strlen(szTCTIME),
+		(int)(30-strlen(szTCTIME)),
 		"Added time",
 		szTCTIME,
 		time2str( ptc->nAddedTime, 0 ) );
     if (ptc->nPointAllowance)
 	outputf("%*s%-*s (%s): %9s\n", 2*level,"",
-		30-strlen(szTCPOINT),
+		(int)(30-strlen(szTCPOINT)),
 		"Time per point",
 		szTCPOINT,
 		time2str(ptc->nPointAllowance, 0));
@@ -393,16 +393,16 @@ static void showTimeControl( timecontrol *ptc, int level, int levels )
 	TC_FISCHER == ptc->timing ||
 	TC_BRONSTEIN == ptc->timing)
 	outputf("%*s%-*s (%s): %9s\n", 2*level,"",
-		30-strlen(szTCMOVE),
+		(int)(30-strlen(szTCMOVE)),
 		"Time per move",
 		szTCMOVE,
 		time2str(ptc->nMoveAllowance, 0));
     if (ptc->dMultiplier != 1.0) 
 	outputf("%*s%-*s (%s): %9s\n", 2*level,"",
-		30-strlen(szTCMULT),
+		(int)(30-strlen(szTCMULT)),
 		"Scale old time by:",
 		szTCMULT,
-		time2str(ptc->dMultiplier, 0)
+		time2str((int)ptc->dMultiplier, 0)
 		);
 
 
@@ -904,13 +904,9 @@ static char staticBuf[20];
 }
 
 
-#if USE_GUI
 #if USE_GTK
 extern gboolean UpdateClockNotify(gpointer *p)
 #else
-extern int UpdateClockNotify(event *pev, void *p)
-#endif
-#else
 extern int UpdateClockNotify(void *p)
 #endif
 {
