@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: timecontrol.h,v 1.6 2004/02/12 10:42:56 uid68519 Exp $
+ * $Id: timecontrol.h,v 1.9 2006/06/22 18:55:07 c_anthon Exp $
  */
 
 #ifndef _TIMECONTROL_H_
@@ -77,13 +77,9 @@ extern char *FormatClock(struct timeval * ptl , char *buf);
  * issue a 
  * MOVE_TIME record if time has run out
  */ 
-#if USE_GUI
 #if USE_GTK
 extern gboolean UpdateClockNotify(gpointer *p); 
 #else
-extern int UpdateClockNotify(event *pev, void *p); 
-#endif
-#else
 extern int UpdateClockNotify(void *p);
 #endif
 
@@ -96,5 +92,5 @@ extern void SetDefaultTC ();
 extern void SaveTimeControlSettings( FILE *pf );
 extern void CommandShowTCTutorial ();
 
-#endif // USE_TIMECONTROL
+#endif /* USE_TIMECONTROL */
 #endif /* _TIMECONTROL_H_ */
