@@ -18,7 +18,7 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* $Id: timer.c,v 1.6 2004/02/02 19:02:51 uid67713 Exp $
+* $Id: timer.c,v 1.7 2005/09/14 21:37:07 Superfly_Jon Exp $
 */
 
 #include "config.h"
@@ -62,6 +62,8 @@ double get_time()
 
 #else
 
+#if 1
+
 double get_time()
 {	/* Return elapsed time in milliseconds */
 	struct timeval tv;
@@ -70,4 +72,31 @@ double get_time()
 	return tv.tv_sec * 1000 + tv.tv_usec / 1000;
 }
 
+#else
+
+double perFreq = 0;
+
+int setup_timer()
+{
+    perFreq = __get_clockfreq() / 1000.0;
+     return 1;
+}
+
+double get_time()
+{    /* Return elapsed time in milliseconds */
+    if (!perFreq)
+    {
+        if (!setup_timer())
+            return clock() / 1000.0;
+    }
+{
+    unsigned long long int val;
+    __asm__ __volatile__("rdtsc" : "=A" (val) : );
+
+    return val / perFreq;
+}
+}
+
+#endif
+
 #endif
